@@ -102,18 +102,6 @@ OC.L10N.register(
     "Date" : "Datum",
     "Tags" : "Etikette",
     "Custom" : "Eie",
-    "Message source" : "Boodskapbron",
-    "Recipient" : "Ontvanger",
-    "Priority" : "Prioriteit",
-    "Reset" : "Herstel",
-    "Client ID" : "Kliënt-ID",
-    "User" : "Gebruiker",
-    "Host" : "Gasheer",
-    "Port" : "Poort",
-    "Valid until" : "Geldig tot",
-    "Certificate" : "Sertifikaat",
-    "Submit" : "Dien in",
-    "Connect your mail account" : "Koppel u posrekening",
     "All" : "Alle",
     "Drafts" : "Konsepte",
     "Favorites" : "Gunstelinge",
@@ -126,7 +114,6 @@ OC.L10N.register(
     "Forwarding to %s" : "Stuur aan na %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
     "Redirect" : "Herverwys",
-    "The link leads to %s" : "Die skakel lei na %s",
-    "Actions" : "Aksies"
+    "The link leads to %s" : "Die skakel lei na %s"
 },
 "nplurals=2; plural=(n != 1);");
