@@ -49,16 +49,6 @@ OC.L10N.register(
     "Close" : "Bağla",
     "Date" : "Date",
     "Tags" : "Işarələr",
-    "Not found" : "Tapılmadı",
-    "Priority" : "Prioritet",
-    "Reset" : "Sıfırla",
-    "Client ID" : "Müştəri İD-s",
-    "Client secret" : "Müxtəri sirri",
-    "User" : "User",
-    "Host" : "Şəbəkədə ünvan",
-    "Port" : "Port",
-    "Valid until" : "Vaxtadək keçərlidir",
-    "Certificate" : "Sertifikat",
     "All" : "Hamısı",
     "Drafts" : "Qaralamalar",
     "Favorites" : "Sevimlilər",
@@ -66,7 +56,6 @@ OC.L10N.register(
     "Junk" : "Önəmsiz",
     "Sent" : "Göndərildi",
     "Trash" : "Zibil",
-    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi",
-    "Actions" : "İşlər"
+    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi"
 },
 "nplurals=2; plural=(n != 1);");
