@@ -167,6 +167,7 @@ OC.L10N.register(
     "Custom date and time" : "Персонализирана дата и час",
     "Enter a date" : "Въведете дата",
     "Choose" : "Изберете",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Прикачените файлове надвишават разрешения размер на прикачени файлове от {size}. Моля, вместо това да споделите файловете чрез връзка.","Прикачените файлове надвишават разрешения размер на прикачени файлове от {size}. Моля, вместо това да споделите файловете чрез връзка."],
     "Choose a file to add as attachment" : "Избери файл за прикачване",
     "Choose a file to share as a link" : "Изберете файл, който да споделите като връзка",
     "_{count} attachment_::_{count} attachments_" : ["{count} прикачени файлове","{count} прикачени файлове"],
@@ -399,148 +400,6 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Името на етикета е скрит системен етикет",
     "Tag already exists" : "Етикетът вече съществува",
     "An error occurred, unable to create the tag." : "Възникна грешка, не може да се създаде етикет.",
-    "Add default tags" : "Добавяне на етикети по подразбиране",
-    "Add tag" : "Добавяне на етикет",
-    "Saving tag …" : "Записване на етикет ...",
-    "Could not load your message thread" : " Нишката на вашето съобщение не можа да се зареди",
-    "The thread doesn't exist or has been deleted" : "Нишката не съществува или е била изтрита",
-    "Loading thread" : "Зареждане на нишка",
-    "Not found" : "Не е намерен",
-    "Encrypted & verified " : "Криптирано и потвърдено",
-    "Signature verified" : "Подписът е потвърден",
-    "Signature unverified " : "Подписът не е потвърден",
-    "This message was encrypted by the sender before it was sent." : "Това съобщение е било криптирано от изпращача преди да бъде изпратено.",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Това съобщение съдържа проверен цифров подпис S/MIME. Съобщението не е променяно след изпращането му.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Това съобщение съдържа непроверен цифров S/MIME подпис. Възможно е съобщението да е било променено, след както е изпратено, или сертификатът на подписаният да е ненадежден.",
-    "Reply all" : "Отговаряне на всички",
-    "Unsubscribe" : "Отписване",
-    "Reply to sender only" : "Отговор само на подателя",
-    "Mark as unfavorite" : "Маркиране като непредпочитано",
-    "Mark as favorite" : "Маркиране като любими",
-    "Mark as unread" : "Маркиране като непрочетено",
-    "Mark as read" : "Маркиране като прочетено",
-    "Message source" : "Източник на съобщение",
-    "Unsubscribing will stop all messages from the mailing list {sender}" : "Прекратяването на абонамента ще спре всички съобщения от пощенския списък {sender}",
-    "Could not remove trusted sender {sender}" : "Не можа да бъде премахнат доверен подател {sender}",
-    "No senders are trusted at the moment." : "В момента няма доверени податели.",
-    "Untitled event" : "Събитие без заглавие",
-    "(organizer)" : "(организатор)",
-    "Import into {calendar}" : "Импортиране в {calendar}",
-    "Event imported into {calendar}" : "Събитието е импортирано в {calendar}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Полет {flightNr} от {depAirport} до {arrAirport}",
-    "Airplane" : "Самолет",
-    "Reservation {id}" : "Резервация {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} от {depStation} до {arrStation}",
-    "Train from {depStation} to {arrStation}" : "Влак от {depStation} до {arrStation}",
-    "Train" : "Влак",
-    "Flag" : "Знаме",
-    "Recipient" : "Получател",
-    "Operator" : "Оператор",
-    "contains" : "съдържа",
-    "matches" : "съвпадения",
-    "Priority" : "Приоритет",
-    "Successfully updated config for \"{domain}\"" : "Конфигурацията за „{domain}“ беше актуализирана успешно",
-    "Error saving config" : "Грешка при записване на конфигурацията",
-    "Saved config for \"{domain}\"" : "Конфигурацията за „{domain}“ е записана",
-    "Could not save provisioning setting" : "Настройката за осигуряване не можа да бъде записана",
-    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Успешно осигурени {count} профили.","Успешно осигурени {count} профили."],
-    "There was an error when provisioning accounts." : "Възникна грешка при осигуряването на профили.",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Успешно изтрити и неосигурени профили за „{domain}“",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Грешка при изтриване и неосигуряване на профили за „{domain}“",
-    "Mail app" : "Приложение за поща",
-    "The mail app allows users to read mails on their IMAP accounts." : "Приложението за поща позволява на потребителите да четат имейли в своите IMAP профили.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Тук можете да намерите настройки за целия екземпляр. Потребителските настройки се намират в самото приложение (долния ляв ъгъл).",
-    "Account provisioning" : "Осигуряване на профил",
-    "A provisioning configuration will provision all accounts with a matching email address." : "Конфигурацията за осигуряване ще предостави на всички профили съответстващ имейл адрес.",
-    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Използването на заместващия символ (*) в полето на домейн за осигуряване, ще създаде конфигурация, която се прилага за всички потребители, при условие че не съвпадат с друга конфигурация.",
-    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Механизмът за осигуряване ще даде приоритет на конкретни конфигурации на домейни пред конфигурацията на домейн със заместващи символи.",
-    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Ако бъде намерена нова съответстваща конфигурация, след като потребителят вече е бил осигурен с друга конфигурация, новата конфигурация ще има предимство и потребителят ще бъде повторно обезпечен с конфигурацията.",
-    "There can only be one configuration per domain and only one wildcard domain configuration." : "Може да има само една конфигурация на домейн и само една конфигурация на домейн със заместващи символи.",
-    "These settings can be used in conjunction with each other." : "Тези настройки могат да се използват свързани една с друга.",
-    "If you only want to provision one domain for all users, use the wildcard (*)." : "Ако искате да осигурите само един домейн за всички потребители, използвайте заместващия символ (*).",
-    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Тази настройка има най-голям смисъл само ако използвате същия потребителски вътрешен сървър за вашия Nextcloud и пощенски сървър на вашата организация.",
-    "Provisioning Configurations" : "Конфигурации за осигуряване",
-    "Add new config" : "Добавяне на нова конфигурация",
-    "Provision all accounts" : "Осигуряване на всички профили",
-    "Allow additional mail accounts" : "Разрешаване на допълнителни пощенски профили",
-    "Allow additional Mail accounts from User Settings" : "Разрешаване на допълнителни пощенски профили от настройките на потребителя",
-    "Anti Spam Service" : "Услуга за защита от нежелана поща",
-    "You can set up an anti spam service email address here." : "Можете да настроите имейл адрес за услуга за защита от нежелана поща тук.",
-    "Any email that is marked as spam will be sent to the anti spam service." : "Всеки имейл, който е маркиран като нежелана поща, ще бъде изпратен до услугата за защита от нежелана поща.",
-    "Gmail integration" : "Gmail интеграция",
-    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail позволява на потребителите да имат достъп до електронната си поща чрез IMAP. От съображения за сигурност този достъп е възможен само с връзка OAuth 2.0 или профили в Google, които използват двустепенно удостоверяване и пароли за приложения.",
-    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Трябва да регистрирате нов клиентски идентификатор за \"уеб приложение\" в конзолата на облачното пространство Google Cloud. Добавете URL {url} като оторизиран URI за пренасочване.",
-    "Microsoft integration" : "Microsoft интеграция",
-    "Successfully set up anti spam email addresses" : "Успешно настроени имейл адреси срещу нежелана поща",
-    "Error saving anti spam email addresses" : "Грешка при записване на имейл адреси срещу нежелана поща",
-    "Successfully deleted anti spam reporting email" : "Успешно изтрит имейл за сигнали срещу нежелана поща",
-    "Error deleting anti spam reporting email" : "Грешка при изтриването на имейл за сигнали срещу нежелана поща",
-    "Anti Spam" : "Защита от нежелана поща",
-    "Add the email address of your anti spam report service here." : "Добавяне на имейл адреса на вашата услуга за докладване на нежелана поща тук.",
-    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Когато използвате тази настройка, имейл с отчет ще бъде изпратен до сървъра за отчети за НЕЖЕЛАНА ПОЩА, когато потребителят щракне върху „Маркиране като нежелана поща“.",
-    "The original message will be attached as a \"message/rfc822\" attachment." : "Оригиналното съобщение ще бъде прикачено като прикачен файл \"message/rfc822\".",
-    "\"Mark as Spam\" Email Address" : "Имейл адрес „Маркиране като нежелана поща“.",
-    "\"Mark Not Junk\" Email Address" : "Имейл адрес „Маркиране, че не е отпадък“.",
-    "Reset" : "Възстановяване",
-    "Google integration configured" : "Конфигурирана е интеграция с Google",
-    "Could not configure Google integration" : "Не можа да се конфигурира интеграцията на Google",
-    "Google integration unlinked" : "Премахната е връзката с интеграцията на Google",
-    "Could not unlink Google integration" : "Не можа да се премахне връзката с интеграцията на Google",
-    "Client ID" : "Идентификатор на клиент",
-    "Client secret" : "Тайна на клиент",
-    "Unlink" : "Прекратяване на връзката",
-    "Microsoft integration configured" : "Конфигурирана е интеграцията на Microsoft",
-    "Could not configure Microsoft integration" : "Не можа да се конфигурира интеграцията на Microsoft",
-    "Microsoft integration unlinked" : "Премахната е връзката с интеграцията на Microsoft",
-    "Could not unlink Microsoft integration" : " Не можа да се премахне връзката с интеграцията на Microsoft",
-    "Tenant ID (optional)" : "Идентификатор на клиент (по избор)",
-    "Domain Match: {provisioningDomain}" : "Съвпадение на домейна: {provisioningDomain}",
-    "Email: {email}" : "Имейл: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} ({ssl} криптиране)",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} на {host}:{port} ({ssl} криптиране)",
-    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Сито: {user} на {host}:{port} ({ssl} криптиране)",
-    "Configuration for \"{provisioningDomain}\"" : "Конфигурация за „{provisioningDomain}“",
-    "Provisioning domain" : "Осигуряващ домейн",
-    "Email address template" : "Шаблон за имейл адрес",
-    "IMAP" : "IMAP",
-    "User" : "Потребител",
-    "Host" : "Хост",
-    "Port" : "Порт",
-    "SMTP" : "SMTP",
-    "Sieve" : "Сито",
-    "Enable sieve integration" : "Активиране на интегрирането на сито",
-    "LDAP aliases integration" : "Интегриране на LDAP псевдоними",
-    "Enable LDAP aliases integration" : "Активиране на интеграцията на LDAP псевдоними",
-    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Интегрирането на LDAP псевдоними, чете атрибут от конфигурираната LDAP директория, за да осигури имейл псевдоними.",
-    "LDAP attribute for aliases" : "LDAP атрибут за псевдоними",
-    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Атрибут с няколко стойности за предоставяне на имейл псевдоними. За всяка стойност се създава псевдоним. Псевдонимите, съществуващи в Nextcloud, които не са в LDAP директорията, се изтриват.",
-    "Save Config" : "Записване на конфигурацията",
-    "Unprovision & Delete Config" : "Отмяна на осигурявне и изтриване на конфигурация",
-    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% и %EMAIL% ще бъдат заменени с UID и имейл на потребителя",
-    "With the settings above, the app will create account settings in the following way:" : "С настройките по-горе приложението ще създаде настройки на профил по следния начин:",
-    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Предоставеният сертификат PKCS #12 трябва да съдържа поне един сертификат и само един частен ключ.",
-    "Failed to import the certificate. Please check the password." : "Неуспешно импортиране на сертификата. Моля, проверете паролата.",
-    "Certificate imported successfully" : "Успешно импортиране на сертификата",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Неуспешно импортиране на сертификата. Моля, уверете се, че частният ключ съответства на сертификата и не е защитен с парола.",
-    "Failed to import the certificate" : "Неуспешно импортиране на сертификата",
-    "S/MIME certificates" : "S/MIME сертификати",
-    "Certificate name" : "Име на сертификата",
-    "E-mail address" : "Имейл адрес",
-    "Valid until" : "Валиден до",
-    "Delete certificate" : "Изтриване на сертификат",
-    "No certificate imported yet" : "Все още няма импортиран сертификат",
-    "Import certificate" : "Импортиране /внасяне/ на сертификат",
-    "Import S/MIME certificate" : "Импортиране на S/MIME сертификат",
-    "PKCS #12 Certificate" : "Сертификат PKCS #12",
-    "PEM Certificate" : "Сертификат PEM",
-    "Certificate" : "Сертификат",
-    "Private key (optional)" : "Частен ключ (по избор)",
-    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Частният ключ е необходим само ако възнамерявате да изпращате подписани и криптирани имейли, като използвате този сертификат.",
-    "Submit" : "Изпращане",
-    "Account connected" : "Профилът е свързан",
-    "You can close this window" : "Можете да затворите този прозорец",
-    "Connect your mail account" : "Свързване към ваш имейл профил",
-    "To add a mail account, please contact your administrator." : "Моля да се свържете с вашия администратор, за да добавите пощенски профил.",
     "All" : "Всички",
     "Drafts" : "Чернови",
     "Favorites" : "Любими",
@@ -569,8 +428,6 @@ OC.L10N.register(
     "Redirect" : "Пренасочване",
     "The link leads to %s" : "Връзката води до %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите тази страница, може да се върнете към <a href=\"%s\">Поща</a>.",
-    "Continue to %s" : "Продължи към %s",
-    "Actions" : "Действия",
-    "New action" : "Ново действие"
+    "Continue to %s" : "Продължи към %s"
 },
 "nplurals=2; plural=(n != 1);");
