@@ -56,15 +56,6 @@ OC.L10N.register(
     "Close" : "Serriñ",
     "Date" : "Deiz",
     "Tags" : "Klavioù",
-    "Translate to" : "Treiñ e",
-    "Actions" : "Oberoù",
-    "Client ID" : "ID kliant",
-    "User" : "Implijer",
-    "Host" : "Ostiz",
-    "Port" : "Porzh",
-    "Valid until" : "Gwir betek",
-    "Submit" : "Kinnig",
-    "Account connected" : "Kont kenstaged",
     "All" : "Pep tra",
     "Favorites" : "Pennrolloù",
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
