@@ -91,13 +91,6 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Tagiau",
     "Custom" : "Cyfaddas",
-    "Not found" : "Heb ei ganfod",
-    "Untitled event" : "Digwyddiad di-deitl",
-    "(organizer)" : "(trefnydd)",
-    "Recipient" : "Derbynnydd",
-    "User" : "User",
-    "Certificate" : "Tystysgrif",
-    "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
     "All" : "Popeth",
     "Drafts" : "Drafftiau",
     "Favorites" : "Ffefrynnau",
@@ -119,7 +112,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
     "Redirect" : "Ailgyfeirio",
     "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
-    "Continue to %s" : "Parhau i %s",
-    "Actions" : "Gweithredoedd"
+    "Continue to %s" : "Parhau i %s"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
