@@ -325,61 +325,6 @@ OC.L10N.register(
     "Save signature" : "Gem underskrift",
     "Saving new tag name …" : "Gemmer nyt tag navn ...",
     "Tag already exists" : "Mærket eksisterer allerede",
-    "Add tag" : "Tilføj Tag",
-    "Loading thread" : "Indlæser tråd",
-    "Not found" : "Ikke fundet",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meddelelse indeholder en verificeret digital S/MIME-signatur. Meddelelsen er ikke ændret, siden den blev sendt.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME-signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
-    "Reply all" : "Besvar alle",
-    "Reply to sender only" : "Besvar kun afsender",
-    "Mark as unread" : "Marker som ulæst",
-    "Mark as read" : "Marker som læst",
-    "Message source" : "Beskedens kildekode",
-    "Go to newest message" : "Gå til nyeste besked",
-    "Translate from" : "Oversæt fra",
-    "Translate to" : "Oversæt til",
-    "Copy translated text" : "Kopier oversat tekst",
-    "Untitled event" : "Unavngiven begivenhed",
-    "(organizer)" : "(arrangør)",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
-    "Airplane" : "Fly",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}",
-    "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}",
-    "Train" : "Tog",
-    "Recipient" : "Modtager",
-    "New filter" : "Nyt filter",
-    "Operator" : "Operatør",
-    "contains" : "indeholder",
-    "matches" : "er lig med",
-    "Priority" : "Prioritet",
-    "Reset" : "Nulstil",
-    "Client ID" : "Klient-ID",
-    "Client secret" : "Klient hemmelighed",
-    "IMAP" : "IMAP",
-    "User" : "ruger",
-    "Host" : "Vært",
-    "Port" : "Port",
-    "SMTP" : "SMTP",
-    "Failed to import the certificate. Please check the password." : "Kunne ikke importere certifikatet. Tjek venligst adgangskoden.",
-    "Certificate imported successfully" : "Certifikatet blev importeret",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Kunne ikke importere certifikatet. Sørg for, at den private nøgle matcher certifikatet og ikke er beskyttet af en kode.",
-    "Failed to import the certificate" : "Kunne ikke importere certifikatet",
-    "S/MIME certificates" : "S/MIME certifikater",
-    "Certificate name" : "Certifikatnavn",
-    "E-mail address" : "E-mail adresse",
-    "Valid until" : "Gyldig indtil",
-    "Delete certificate" : "Slet certifikat",
-    "No certificate imported yet" : "Intet certifikat importeret endnu",
-    "Import certificate" : "Importér certifikat",
-    "Import S/MIME certificate" : "Importer S/MIME-certifikat",
-    "PKCS #12 Certificate" : "PKCS #12 Certifikat",
-    "PEM Certificate" : "PEM Certifikat",
-    "Certificate" : "Certifikat",
-    "Private key (optional)" : "Privat nøgle (valgfrit)",
-    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøgle er kun påkrævet, hvis du har til hensigt at sende signerede og krypterede e-mails ved hjælp af dette certifikat.",
-    "Submit" : "Tilføj",
-    "Account connected" : "Kontoen er tilknyttet",
-    "Connect your mail account" : "Forbind din mail konto",
     "All" : "Alle",
     "Drafts" : "Udkast",
     "Favorites" : "Favoritter",
@@ -405,9 +350,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
-    "Continue to %s" : "Videre til %s",
-    "New test" : "Nyeste test",
-    "Actions" : "Handlinger",
-    "New action" : "Ny handling"
+    "Continue to %s" : "Videre til %s"
 },
 "nplurals=2; plural=(n != 1);");
