@@ -309,59 +309,6 @@ OC.L10N.register(
     "Delete tag" : "Διαγραφή ετικέτας",
     "Tag already exists" : "Υπάρχει ήδη η ετικέτα",
     "An error occurred, unable to create the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η δημιουργία της ετικέτας.",
-    "Add default tags" : "Προσθήκη προεπιλεγμένων ετικετών",
-    "Add tag" : "Προσθήκη ετικέτας",
-    "Saving tag …" : "Αποθήκευση ετικέτας…",
-    "Could not load your message thread" : "Δεν ήταν δυνατή η φόρτωση του μηνύματός σας",
-    "Not found" : "Δε βρέθηκε",
-    "Reply all" : "Απάντηση σε όλους",
-    "Unsubscribe" : "Κατάργηση εγγραφής",
-    "Reply to sender only" : "Απάντηση μόνο στον αποστολέα",
-    "Mark as favorite" : "Επισήμανση ως αγαπημένο",
-    "Mark as unread" : "επισήμανση ως μή-αναγνωσμένο",
-    "Mark as read" : "Σήμανση ως αναγνωσμένο",
-    "Message source" : "Πηγή μηνύματος",
-    "Could not remove trusted sender {sender}" : "Δεν ήταν δυνατή η κατάργηση του αξιόπιστου αποστολέα {sender}",
-    "No senders are trusted at the moment." : "Κανένας αποστολέας δεν είναι αξιόπιστος αυτή τη στιγμή.",
-    "Untitled event" : "Συμβάν χωρίς όνομα",
-    "(organizer)" : "(organizer)",
-    "Import into {calendar}" : "Εισαγωγή στο {calendar}",
-    "Event imported into {calendar}" : "Το συμβάν εισήχθη στο {calendar}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Πτήση {flightNr} από {depAirport} προς {arrAirport}",
-    "Airplane" : "Αεροπλάνο",
-    "Reservation {id}" : "Κράτηση {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} από {depStation} προς {arrStation}",
-    "Train from {depStation} to {arrStation}" : "Τρένο από {depStation} προς {arrStation}",
-    "Train" : "Τρένο",
-    "Flag" : "Σημαία",
-    "Recipient" : "Παραλήπτης",
-    "Delete filter" : "Διαγραφή φίλτρου",
-    "Operator" : "Διαχειριστής",
-    "contains" : "περιέχει",
-    "matches" : "ταιριάζει",
-    "Priority" : "Προτεραιότητα",
-    "Mail app" : "Εφαρμογή αλληλογραφίας",
-    "The mail app allows users to read mails on their IMAP accounts." : "Η εφαρμογή ταχυδρομείου επιτρέπει στους χρήστες να διαβάζουν μηνύματα από τους λογαριασμούς τους IMAP.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Εδώ μπορείτε να βρείτε ρυθμίσεις για το περιστατικό. Οι συγκεκριμένες ρυθμίσεις χρήστη βρίσκονται στην ίδια την εφαρμογή (κάτω αριστερή γωνία).",
-    "Reset" : "Επαναφορά",
-    "Client ID" : "Αναγνωριστικό πελάτη",
-    "Client secret" : "Μυστικό πελάτη",
-    "Unlink" : "Αποσύνδεση",
-    "Email: {email}" : "Email: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} σε {host}:{port} ({ssl} encryption)",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} σε {host}:{port} ({ssl} encryption)",
-    "IMAP" : "IMAP",
-    "User" : "Χρήστης",
-    "Host" : "Διακομιστής",
-    "Port" : "Θύρα",
-    "SMTP" : "SMTP",
-    "With the settings above, the app will create account settings in the following way:" : "Με τις παραπάνω ρυθμίσεις, η εφαρμογή θα δημιουργήσει τις ρυθμίσεις λογαριασμού με τον ακόλουθο τρόπο:",
-    "E-mail address" : "E-mail διεύθυνση",
-    "Valid until" : "Έγκυρο έως",
-    "Certificate" : "Πιστοποιητικό",
-    "Submit" : "Υποβολή",
-    "Account connected" : "Συνδεδεμένος λογαριασμός",
-    "Connect your mail account" : "Συνδέστε το λογαριασμό αλληλογραφίας σας",
     "All" : "'Ολα",
     "Drafts" : "Πρόχειρα",
     "Favorites" : "Αγαπημένα",
@@ -388,8 +335,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Κάντε κλικ εδώ εάν δεν ανακατευθυνθείτε αυτόματα μέσα σε λίγα δευτερόλεπτα.",
     "Redirect" : "Ανακατεύθυνση",
     "The link leads to %s" : "Αυτός ο σύνδεσμος οδηγεί στο %s",
-    "Continue to %s" : "Συνέχεια στο %s",
-    "Actions" : "Ενέργειες",
-    "New action" : "Νέα ενέργεια"
+    "Continue to %s" : "Συνέχεια στο %s"
 },
 "nplurals=2; plural=(n != 1);");
