@@ -93,21 +93,6 @@ OC.L10N.register(
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
     "Custom" : "Personalizado",
-    "Add tag" : "Agregar etiqueta",
-    "Recipient" : "Destinatario",
-    "Operator" : "Operador",
-    "matches" : "coincide",
-    "Priority" : "Prioridad",
-    "Reset" : "Restaurar",
-    "Client ID" : "ID del cliente",
-    "Client secret" : "Secreto del cliente",
-    "User" : "Ususario",
-    "Host" : "Servidor",
-    "Port" : "Puerto",
-    "Valid until" : "Válido hasta",
-    "Certificate" : "Certificado",
-    "Submit" : "Enviar",
-    "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
     "Favorites" : "Favoritos",
@@ -126,7 +111,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s",
-    "Actions" : "Acciones"
+    "Continue to %s" : "Continuar a %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
