@@ -352,27 +352,6 @@ OC.L10N.register(
     "Last 7 days" : "Últimos 7 días",
     "Custom" : "Personalizado",
     "Tag already exists" : "La etiqueta ya existe",
-    "Add tag" : "Agregar etiqueta",
-    "Not found" : "No encontrado",
-    "Translate from" : "Traducir desde",
-    "Untitled event" : "Evento sin título",
-    "(organizer)" : "(organizador)",
-    "Recipient" : "Destinatario",
-    "Operator" : "Operador",
-    "contains" : "contiene",
-    "matches" : "coincide",
-    "Priority" : "Prioridad",
-    "Reset" : "Reiniciar",
-    "Client ID" : "ID del cliente",
-    "Client secret" : "Secreto del cliente",
-    "User" : "Usuario",
-    "Host" : "Servidor",
-    "Port" : "Puerto",
-    "Valid until" : "Válido hasta",
-    "Certificate" : "Certificado",
-    "Submit" : "Enviar",
-    "Account connected" : "Cuenta conectada",
-    "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
     "Favorites" : "Favoritos",
@@ -395,7 +374,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s",
-    "Actions" : "Acciones"
+    "Continue to %s" : "Continuar a %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
