@@ -216,6 +216,7 @@ OC.L10N.register(
     "Custom date and time" : "Data eta ordu pertsonalizatuak",
     "Enter a date" : "Sartu data bat",
     "Choose" : "Aukeratu",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Eranskinek baimendutako {size} -ko eranskin tamaina gainditzen du. Partekatu fitxategia esteka bidez horren ordez.","Eranskinek baimendutako {size} -ko eranskin tamaina gainditzen du. Partekatu fitxategia esteka bidez horren ordez."],
     "Choose a file to add as attachment" : "Aukeratu fitxategia eranskin gisa gehitzeko",
     "Choose a file to share as a link" : "Aukeratu fitxategi bat esteka bezala partekatzeko",
     "_{count} attachment_::_{count} attachments_" : ["Eranskin {count}","{count} eranskin"],
@@ -522,206 +523,6 @@ OC.L10N.register(
     "Tag already exists" : "Etiketa dagoeneko existitzen da",
     "Tag name cannot be empty" : "Etiketaren izena ezin da hutsik egon",
     "An error occurred, unable to create the tag." : "Errore bat gertatu da, ezin da etiketa sortu.",
-    "Add default tags" : "Gehitu etiketa lehenetsiak",
-    "Add tag" : "Gehitu etiketa",
-    "Saving tag …" : "Etiketa gordetzen",
-    "Task created" : "Eginkizuna sortuta",
-    "Could not create task" : "Ezin izan da eginkizuna sortu",
-    "No calendars with task list support" : "Ez dago eginkizun-zerrendarik onartzen duen egutegirik",
-    "Summarizing thread failed." : "Haria laburbiltzeak huts egin du.",
-    "Could not load your message thread" : "Ezin izan da zure mezuen haria kargatu",
-    "The thread doesn't exist or has been deleted" : "Haria ez da existitzen edo ezabatu egin da",
-    "Loading thread" : "Haria kargatzen",
-    "Not found" : "Ez da aurkitu",
-    "Encrypted & verified " : "Enkriptatuta eta egiaztatua",
-    "Signature verified" : "Sinadura egiaztatua",
-    "Signature unverified " : "Sinadura egiaztatu gabe",
-    "This message was encrypted by the sender before it was sent." : "Mezu hau igorleak enkriptatu zuen bidali aurretik.",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Mezu honek S/MIME sinadura digital egiaztatua dauka. Mezua ez da aldatu bidali zenetik.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Mezu honek egiaztatu gabeko S/MIME sinadura digital bat dauka. Baliteke mezua bidali zenetik aldatu izana edo sinatzailearen ziurtagiria fidagarria ez izatea.",
-    "Reply all" : "Erantzun denei",
-    "Unsubscribe request sent" : "Harpidetza kentze eskaera bidalita",
-    "Could not unsubscribe from mailing list" : "Ezin izan da posta-zerrendako harpidetza kendu",
-    "Disable reminder" : "Desgaitu gogorarazpena",
-    "Unsubscribe" : "Harpidetza kendu",
-    "Reply to sender only" : "Erantzun bakarrik igorleari",
-    "Mark as unfavorite" : "Markatu ez gogoko gisa",
-    "Mark as favorite" : "Markatu gogoko gisa",
-    "Mark as unread" : "Markatu irakurri gabeko gisa",
-    "Mark as read" : "Markatu irakurritako gisa",
-    "Message source" : "Mezuaren iturburua",
-    "Unsubscribe via link" : "Harpidetza kendu esteka bidez",
-    "Unsubscribing will stop all messages from the mailing list {sender}" : "Harpidetza kentzeak {sender} posta-zerrendako mezu guztiak geldituko ditu",
-    "Send unsubscribe email" : "Bidali harpidetza kentzeko mezu elektronikoa",
-    "Unsubscribe via email" : "Harpidetza kendu mezu elektroniko bidez",
-    "{name} Assistant" : "{name} laguntzailea",
-    "Go to latest message" : "Joan azken mezura",
-    "Go to newest message" : "Joan mezu berrienera",
-    "Thread summary" : "Hariaren laburpena",
-    "The message could not be translated" : "Ezin izan da mezu hau itzuli",
-    "Translation copied to clipboard" : "Itzulpena arbelera kopiatu da",
-    "Translation could not be copied" : "Ezin izan da itzulpena kopiatu",
-    "Translate message" : "Itzuli mezua",
-    "Translate from" : "Itzuli honetatik",
-    "Translate to" : "Itzuli honetara",
-    "Translating" : "Itzultzen",
-    "Copy translated text" : "Kopiatu itzulitako testua",
-    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Desgaitu zaborrontziaren atxikipena eremua hutsik utziz edo 0 moduan ezarriz. Zaborrontziaren atxikipena gaitu ondoren ezabatzen diren mezuak soilik prozesatuko dira.",
-    "Could not remove trusted sender {sender}" : "Ezin izan da {sender} igorle fidagarria kendu",
-    "No senders are trusted at the moment." : "Une honetan ez da igorle fidagarririk.",
-    "Untitled event" : "Izenik gabeko gertaera",
-    "(organizer)" : "(antolatzailea)",
-    "Import into {calendar}" : "Inportatu {calendar} egutegira",
-    "Event imported into {calendar}" : "Gertaera inportatu da {calendar} egutegira",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{flightNr} hegaldia {depAirport} aireportutik {arrAirport} aireportura",
-    "Airplane" : "Hegazkina",
-    "Reservation {id}" : "Erreserba {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} trena {depStation} geltokitik {arrStation} geltokira",
-    "Train from {depStation} to {arrStation}" : "Trena {depStation} geltokitik {arrStation} geltokira",
-    "Train" : "Trena",
-    "Delete action" : "Ezabatu ekintza",
-    "Flag" : "Bandera",
-    "The stop action ends all processing" : "Gelditze-ekintzak prozesua amaitzen du.",
-    "Recipient" : "Hartzailea",
-    "Delete filter" : "Ezabatu iragazkia",
-    "Delete mail filter {filterName}?" : "Ezabatu {filterName} posta-iragazkia?",
-    "Are you sure to delete the mail filter?" : "Ziur zaude posta-iragazkia ezabatu nahi duzula?",
-    "New filter" : "Iragazki berria",
-    "Filter saved" : "Iragazkia gordeta",
-    "Could not save filter" : "Ezin izan da iragazkia gorde",
-    "Filter deleted" : "Iragazkia ezabatuta",
-    "Could not delete filter" : "Ezin izan da iragazkia ezabatu",
-    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Kontrolatu zure posta elektronikoaren kaosa. Iragazkiek garrantzitsuena lehenestu eta zaborra ezabatzen laguntzen dizute.",
-    "Filter is active" : "Iragazkia gaituta dago",
-    "Filter is not active" : "Iragazkia desgaituta dago",
-    "Operator" : "Eragilea",
-    "contains" : "dauka",
-    "matches" : "bat dator",
-    "Delete test" : "Ezabatu proba",
-    "Update mail filter" : "Eguneratu posta iragazkia",
-    "Filter name" : "Iragaziaren izena",
-    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "Zure posta-zerbitzarian sartzen diren posta elektronikoei aplikatzen zaizkie probak. Eremu hauek probatzen dira: gaia (posta elektronikoaren gai-lerroa), bidaltzailea eta hartzailea. Honako eragile hauek erabil ditzakezu eremu horietarako baldintzak zehazteko:",
-    "An exact match. The field must be identical to the provided value." : "Bat etortze zehatza. Eremuak emandako balioaren berdina izan behar du.",
-    "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Azpikate bat etortzea. Eremua bat dator emandako balioa barruan badago. Adibidez, \"aireportua\" bat etorriko litzake \"portua\"-rekin.",
-    "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "Patroi bat etortzea komodinak erabiliz. «*» sinboloa edozein karaktere (ezer ez barne) kopuru adierazten du. Bestalde, «?» karaktere bakarra adierazten du. Adibidez «*txosten*» «2024ko txostena»-rekin bat etorriko litzateke.",
-    "Actions are triggered when the specified tests are true. The following actions are available:" : "Ekintzak zehaztutako probak egiazkoak direnean abiarazten dira. Honako ekintza hauek daude:",
-    "Moves the message into a specified folder." : "Mezua karpeta zehatz batera eramaten du.",
-    "Adds a flag to the message." : "Bandera bat gehitzen dio mezuari.",
-    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Iragazpen scriptaren exekuzioa geldiarazten du. Ekintza honen ondoren ez da iragazki gehiagorik prozesatuko.",
-    "Priority" : "Lehentasuna",
-    "Enable filter" : "Gaitu iragazkia",
-    "Save filter" : "Gorde iragazkia",
-    "Successfully updated config for \"{domain}\"" : "\"{domain}\"-ren konfigurazioa behar bezala eguneratu da",
-    "Error saving config" : "Errorea konfigurazioa gordetzean",
-    "Saved config for \"{domain}\"" : "\"{domain}\"-ren konfigurazioa gorde da",
-    "Could not save provisioning setting" : "Ezin izan da hornidura ezarpena gorde",
-    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} kontua behar bezala hornitu da.","{count} kontuak behar bezala hornitu dira."],
-    "There was an error when provisioning accounts." : "Errore bat gertatu da kontuak hornitzean.",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "\"{domain}\"-ren kontuak behar bezala ezabatu dira.",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errorea gertatu da \"{domain}\"-ren kontuak ezabatzean.",
-    "Could not save default classification setting" : "Ezin izan da sailkapen-ezarpen lehenetsia gorde",
-    "Mail app" : "Posta elektroniko aplikazioa",
-    "The mail app allows users to read mails on their IMAP accounts." : "Posta elektroniko aplikazio honek aukera ematen die erabiltzaileei IMAP kontuetako mezuak irakurtzeko.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Hemen instantzia osoko ezarpenak aurkitu ditzakezu. Erabiltzailearen ezarpen espezifikoak aplikazioan bertan daude (beheko ezkerreko izkinan).",
-    "Account provisioning" : "Kontu horniketa",
-    "A provisioning configuration will provision all accounts with a matching email address." : "Hornidura konfigurazio batek kontu guztiak hornituko ditu helbide elektronikoarekin.",
-    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Hornitze domeinuaren eremuan komodina (*)  erabilita erabiltzaile guztiei aplikatuko zaien konfigurazioa sortuko da, beste konfigurazio batekin bat ez datozenean.",
-    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Hornidura mekanismoak domeinu konfigurazio zehatzak lehenetsiko ditu komodin-domeinuaren konfigurazioaren aurrean.",
-    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Erabiltzailea dagoeneko beste konfigurazio batekin hornitu ondoren bat datorren konfigurazio berri bat aurkitzen bada, konfigurazio berriak izango du lehentasuna eta erabiltzaileari berriro hornituko zaio konfigurazioarekin.",
-    "There can only be one configuration per domain and only one wildcard domain configuration." : "Domeinu bakoitzeko konfigurazio bakarra egon daiteke eta komodin-domeinuaren konfigurazio bakarra.",
-    "These settings can be used in conjunction with each other." : "Ezarpen hauek beste batzuekin batera erabili daitezke.",
-    "If you only want to provision one domain for all users, use the wildcard (*)." : "Bakarrik nahi baduzu erabiltzaile guztientzako domeinua hornitzea, erabili komodina (*).",
-    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Ezarpen honek zentzua dauka zure Nextcloud eta mail zerbitzariek erabiltzaileen atzealde berdina erabiltzen badute zure erakundean.",
-    "Provisioning Configurations" : "Horniketa konfigurazioak",
-    "Add new config" : "Gehitu ezarpen berria",
-    "Provision all accounts" : "Hornitu kontu guztiak",
-    "Allow additional mail accounts" : "Onartu e-mail kontu gehigarriak",
-    "Allow additional Mail accounts from User Settings" : "Onartu posta kontu gehigarriak erabiltzaile ezarpenetatik",
-    "Enable text processing through LLMs" : "Gaitu testuen prozesamendua LLMen bidez",
-    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Posta aplikazioak erabiltzailearen datuak prozesatu ditzake konfiguratutako hizkuntza-ereduaren laguntzaz eta laguntza-funtzioak eskain ditzake, hala nola harien laburpenak, erantzun adimendunak eta gertaeren agendak.",
-    "Enable LLM processing" : "Gaitu LLM prozesatzea",
-    "Enable classification by importance by default" : "Gaitu garrantziaren araberako sailkapena modu lehenetsian",
-    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "Posta aplikazioak sarrerako mezu elektronikoak garrantziaren arabera sailka ditzake ikaskuntza automatikoa erabiliz. Ezaugarri hau lehenespenez gaituta dago, baina lehenespenez desgaitu daiteke hemen. Erabiltzaile indibidualek beren kontuetarako funtzioa aldatzeko aukera izango dute oraindik.",
-    "Enable classification of important mails by default" : "Gaitu mezu garrantzitsuen sailkapena modu lehenetsian",
-    "Anti Spam Service" : "Anti spam zerbitzua",
-    "You can set up an anti spam service email address here." : "Hemen spamaren aurkako zerbitzuaren helbide elektronikoa konfigura dezakezu.",
-    "Any email that is marked as spam will be sent to the anti spam service." : "Spam gisa markatutako edozein mezu elektroniko spamaren aurkako zerbitzura bidaliko da.",
-    "Gmail integration" : "Gmail integrazioa",
-    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail-ek erabiltzaileei euren posta elektronikora sartzeko baimena ematen die IMAP bidez. Segurtasun arrazoiengatik sarbide hori soilik da posible OAuth 2.0 konexio batekin edo bi faktoreko autentifikazioa eta aplikazioen pasahitzak erabiltzen diren Google kontuekin.",
-    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "\"Web aplikazio\" baterako bezero ID berri bat erregistratu behar duzu Google Cloud kontsolan. Gehitu {url} URLa baimendutako birbideratze URI gisa.",
-    "Microsoft integration" : "Microsoft integrazioa",
-    "Successfully set up anti spam email addresses" : "Konfiguratu spamaren aurkako helbide elektronikoak",
-    "Error saving anti spam email addresses" : "Errorea spamaren aurkako helbide elektronikoak gordetzean",
-    "Successfully deleted anti spam reporting email" : "Spamaren aurkako jakinarazpen mezu elektronikoa behar bezala ezabatu da",
-    "Error deleting anti spam reporting email" : "Errorea spamaren aurkako jakinarazpen mezu elektronikoa ezabatzean",
-    "Anti Spam" : "Spamaren aurkakoa",
-    "Add the email address of your anti spam report service here." : "Gehitu hemen spamaren aurkako jakinarazpen-zerbitzuaren helbide elektronikoa .",
-    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Ezarpen hau erabiltzean, jakinarazpen-mezu elektroniko bat bidaliko zaio SPAM jakinarazpen-zerbitzariari erabiltzaile batek \"Markatu spam gisa\"-n klik egiten duenean.",
-    "The original message will be attached as a \"message/rfc822\" attachment." : "Jatorrizko mezua \"message/rfc822\" eranskin gisa erantsiko da.",
-    "\"Mark as Spam\" Email Address" : "\"Markatu Spama gisa\" helbide elektronikoa",
-    "\"Mark Not Junk\" Email Address" : "\"Markatu mezu ez-baztergarri gisa\" helbide elektronikoa",
-    "Reset" : "Berrezarri",
-    "Google integration configured" : "Google integrazioa konfiguratu da",
-    "Could not configure Google integration" : "Ezin izan da Google integrazioa konfiguratu",
-    "Google integration unlinked" : "Desestekatu da Google-ren integrazioa",
-    "Could not unlink Google integration" : "Ezin izan da desestekatu Google integrazioa",
-    "Client ID" : "Bezeroaren IDa",
-    "Client secret" : "Bezeroaren sekretua",
-    "Unlink" : "Deskonektatu",
-    "Microsoft integration configured" : "Microsoft integrazioa konfiguratu da",
-    "Could not configure Microsoft integration" : "Ezin izan da Microsoft integrazioa konfiguratu",
-    "Microsoft integration unlinked" : "Microsoft integrazioa desestekatu da",
-    "Could not unlink Microsoft integration" : "Ezin izan da desestekatu Microsoft integrazioa",
-    "Tenant ID (optional)" : "Maizterraren ID (aukerakoa)",
-    "Domain Match: {provisioningDomain}" : "Bat datorren domeinua: {provisioningDomain}",
-    "Email: {email}" : "Posta helbidea: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} hemen: {host}:{port} ({ssl} encryption)",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} hemen: {host}:{port} ({ssl} encryption)",
-    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} {host}-en: {port} ({ssl} enkriptatzea)",
-    "Configuration for \"{provisioningDomain}\"" : "\"{provisioningDomain}\"-ren konfigurazioa",
-    "Provisioning domain" : "Domeinua hornitzen",
-    "Email address template" : "E-postaren txantiloia",
-    "IMAP" : "IMAP",
-    "User" : "Erabiltzailea",
-    "Host" : "Ostalaria",
-    "Port" : "Ataka",
-    "SMTP" : "SMTP",
-    "Master password" : "Pasahitza nagusia",
-    "Use master password" : "Erabili pasahitza nagusia",
-    "Sieve" : "Sieve",
-    "Enable sieve integration" : "Gaitu sieve integrazioa",
-    "LDAP aliases integration" : "LDAP aliasen integrazioa",
-    "Enable LDAP aliases integration" : "Gaitu LDAP ezizenen integrazioa",
-    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP aliasen integrazioak konfiguratutako LDAP direktorioko atributu bat irakurtzen du posta elektroniko aliasak hornitzeko.",
-    "LDAP attribute for aliases" : "Aliasentzako LDAP atributua",
-    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Balio anitzeko atributu bat posta elektroniko aliasak hornitzeko. Balio bakoitzerako alias bat sortzen da. LDAP direktorioan ez dauden Nextcloud-en dauden aliasak ezabatzen dira.",
-    "Save Config" : "Gorde konfigurazioa",
-    "Unprovision & Delete Config" : "Ez hornitu eta ezabatu konfigurazioa",
-    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% eta%EMAIL% erabiltzailearen UID eta e-postarekin ordeztuko dira",
-    "With the settings above, the app will create account settings in the following way:" : "Goiko ezarpenekin, aplikazioak honako ezarpenak dituzten kontuak sortuko ditu:",
-    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Emandako PKCS #12 ziurtagiriak gutxienez izan behar ditu ziurtagiri bat eta gako pribatu bat zehazki.",
-    "Failed to import the certificate. Please check the password." : "Ezin izan da ziurtagiria inportatu. Mesedez, egiaztatu pasahitza.",
-    "Certificate imported successfully" : "Ziurtagiria ongi inportatu da",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Ezin izan da ziurtagiria inportatu. Mesedez, ziurtatu gako pribatua ziurtagiriarekin bat datorrela eta ez dagoela pasaesaldi batek babestuta.",
-    "Failed to import the certificate" : "Ezin izan da ziurtagiria inportatu",
-    "S/MIME certificates" : "S/MIME ziurtagiriak",
-    "Certificate name" : "Ziurtagiriaren izena",
-    "E-mail address" : "E-mail helbidea",
-    "Valid until" : "Data hau arte baliogarria",
-    "Delete certificate" : "Ezabatu ziurtagiria",
-    "No certificate imported yet" : "Oraindik ez da inportatu ziurtagiririk",
-    "Import certificate" : "Inportatu ziurtagiria",
-    "Import S/MIME certificate" : "Inportatu S/MIME ziurtagiria",
-    "PKCS #12 Certificate" : "PKCS #12 Ziurtagiria",
-    "PEM Certificate" : "PEM Ziurtagiria",
-    "Certificate" : "Ziurtagiria",
-    "Private key (optional)" : "Gako pribatua (aukerakoa)",
-    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Gako pribatua beharrezkoa da  soilik ziurtagiri hau erabiliz sinatutako eta enkriptatutako mezu elektronikoak bidaltzeko asmoa baduzu .",
-    "Submit" : "Bidali",
-    "Account connected" : "Kontua konektatuta",
-    "You can close this window" : "Leiho hau itxi dezakezu",
-    "Connect your mail account" : "Konektatu zure posta kontua",
-    "To add a mail account, please contact your administrator." : "E-mail kontua gehitzeko, kontaktatu zure administratzailearekin, mesedez.",
     "All" : "Denak",
     "Drafts" : "Zirriborroak",
     "Favorites" : "Gogokoak",
@@ -757,12 +558,6 @@ OC.L10N.register(
     "Redirect" : "Birbideratu",
     "The link leads to %s" : "Estekak hona bideratzen du: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
-    "Continue to %s" : "Jarraitu hona: %s",
-    "If all tests pass, then the actions will be executed" : "Proba guztiak gaindituz gero, ekintzak burutu egingo dira",
-    "If one test pass, then the actions will be executed" : "Proba bat gaindituz gero, ekintzak burutu egingo dira",
-    "Tests" : "Probak",
-    "New test" : "Proba berria",
-    "Actions" : "Ekintzak",
-    "New action" : "Ekintza berria"
+    "Continue to %s" : "Jarraitu hona: %s"
 },
 "nplurals=2; plural=(n != 1);");
