@@ -174,6 +174,7 @@ OC.L10N.register(
     "Custom date and time" : "Custom date and time",
     "Enter a date" : "تاریخ را وارد کنید",
     "Choose" : "انتخاب کنید",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["The attachment exceed the allowed attachments size of {size}. Please share the file via link instead.","The attachments exceed the allowed attachments size of {size}. Please share the files via link instead."],
     "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
     "Choose a file to share as a link" : "Choose a file to share as a link",
     "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
@@ -422,162 +423,6 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Tag name is a hidden system tag",
     "Tag already exists" : "تگ از قبل وجود دارد",
     "An error occurred, unable to create the tag." : "An error occurred, unable to create the tag.",
-    "Add default tags" : "Add default tags",
-    "Add tag" : "برچسب اضافه کنید",
-    "Saving tag …" : "Saving tag …",
-    "Task created" : "Task created",
-    "Could not create task" : "Could not create task",
-    "No calendars with task list support" : "No calendars with task list support",
-    "Summarizing thread failed." : "Summarizing thread failed.",
-    "Could not load your message thread" : "Could not load your message thread",
-    "The thread doesn't exist or has been deleted" : "The thread doesn't exist or has been deleted",
-    "Loading thread" : "Loading thread",
-    "Not found" : "پیدا نشد",
-    "Encrypted & verified " : "Encrypted & verified ",
-    "Signature verified" : "Signature verified",
-    "Signature unverified " : "Signature unverified ",
-    "This message was encrypted by the sender before it was sent." : "This message was encrypted by the sender before it was sent.",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted.",
-    "Reply all" : "Reply all",
-    "Unsubscribe request sent" : "Unsubscribe request sent",
-    "Could not unsubscribe from mailing list" : "Could not unsubscribe from mailing list",
-    "Unsubscribe" : "Unsubscribe",
-    "Reply to sender only" : "فقط به فرستنده پاسخ دهید",
-    "Mark as unfavorite" : "Mark as unfavorite",
-    "Mark as favorite" : "Mark as favorite",
-    "Mark as unread" : "علامت به عنوان خوانده‌نشده",
-    "Mark as read" : "علامت به عنوان خوانده‌شده",
-    "Message source" : "Message source",
-    "Unsubscribe via link" : "Unsubscribe via link",
-    "Unsubscribing will stop all messages from the mailing list {sender}" : "Unsubscribing will stop all messages from the mailing list {sender}",
-    "Send unsubscribe email" : "Send unsubscribe email",
-    "Unsubscribe via email" : "Unsubscribe via email",
-    "{name} Assistant" : "{name} Assistant",
-    "Go to latest message" : "Go to latest message",
-    "Go to newest message" : "Go to newest message",
-    "The message could not be translated" : "The message could not be translated",
-    "Translation copied to clipboard" : "Translation copied to clipboard",
-    "Translation could not be copied" : "Translation could not be copied",
-    "Translate message" : "Translate message",
-    "Source language to translate from" : "Source language to translate from",
-    "Translate from" : "Translate from",
-    "Target language to translate into" : "Target language to translate into",
-    "Translate to" : "Translate to",
-    "Translating" : "Translating",
-    "Copy translated text" : "رونوشت متن ترجمه",
-    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed.",
-    "Could not remove trusted sender {sender}" : "Could not remove trusted sender {sender}",
-    "No senders are trusted at the moment." : "No senders are trusted at the moment.",
-    "Untitled event" : "رویداد بدون عنوان",
-    "(organizer)" : "(تنظیم کننده)",
-    "Import into {calendar}" : "{وارد {تقویم",
-    "Event imported into {calendar}" : "{رویداد وارد شده به {تقویم",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{پرواز} {پرواز Nr} از {depAirport} به {arrAirport}",
-    "Airplane" : "هواپیما",
-    "Reservation {id}" : "رزرو {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} از {depStation} تا {arrStation}",
-    "Train from {depStation} to {arrStation}" : "آموزش از {depStation} تا {arrStation} Train",
-    "Train" : "رشته",
-    "Flag" : "Flag",
-    "Delete filter" : "Delete filter",
-    "Operator" : "Operator",
-    "contains" : "contains",
-    "matches" : "مطابق است",
-    "Priority" : "اولویت",
-    "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
-    "Error saving config" : "Error saving config",
-    "Saved config for \"{domain}\"" : "Saved config for \"{domain}\"",
-    "Could not save provisioning setting" : "Could not save provisioning setting",
-    "Mail app" : "برنامه پست الکترونیکی",
-    "The mail app allows users to read mails on their IMAP accounts." : "برنامه نامه الکترونیکی به کاربران این امکان را می دهد تا نامه ها را در حساب های IMAP خود بخوانند.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner).",
-    "Account provisioning" : "Account provisioning",
-    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration.",
-    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration.",
-    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration.",
-    "There can only be one configuration per domain and only one wildcard domain configuration." : "There can only be one configuration per domain and only one wildcard domain configuration.",
-    "These settings can be used in conjunction with each other." : "These settings can be used in conjunction with each other.",
-    "If you only want to provision one domain for all users, use the wildcard (*)." : "If you only want to provision one domain for all users, use the wildcard (*).",
-    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization.",
-    "Provisioning Configurations" : "Provisioning Configurations",
-    "Add new config" : "Add new config",
-    "Anti Spam Service" : "Anti Spam Service",
-    "You can set up an anti spam service email address here." : "You can set up an anti spam service email address here.",
-    "Any email that is marked as spam will be sent to the anti spam service." : "Any email that is marked as spam will be sent to the anti spam service.",
-    "Gmail integration" : "Gmail integration",
-    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI.",
-    "Microsoft integration" : "Microsoft integration",
-    "Successfully set up anti spam email addresses" : "Successfully set up anti spam email addresses",
-    "Error saving anti spam email addresses" : "Error saving anti spam email addresses",
-    "Successfully deleted anti spam reporting email" : "Successfully deleted anti spam reporting email",
-    "Error deleting anti spam reporting email" : "Error deleting anti spam reporting email",
-    "Anti Spam" : "Anti Spam",
-    "Add the email address of your anti spam report service here." : "Add the email address of your anti spam report service here.",
-    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\".",
-    "The original message will be attached as a \"message/rfc822\" attachment." : "The original message will be attached as a \"message/rfc822\" attachment.",
-    "\"Mark as Spam\" Email Address" : "\"Mark as Spam\" Email Address",
-    "\"Mark Not Junk\" Email Address" : "\"Mark Not Junk\" Email Address",
-    "Reset" : "بازنشاندن",
-    "Google integration configured" : "Google integration configured",
-    "Could not configure Google integration" : "Could not configure Google integration",
-    "Google integration unlinked" : "Google integration unlinked",
-    "Could not unlink Google integration" : "Could not unlink Google integration",
-    "Client ID" : "شناسه مشتری",
-    "Client secret" : "رمز مشتری",
-    "Unlink" : "Unlink",
-    "Microsoft integration configured" : "Microsoft integration configured",
-    "Could not configure Microsoft integration" : "Could not configure Microsoft integration",
-    "Microsoft integration unlinked" : "Microsoft integration unlinked",
-    "Could not unlink Microsoft integration" : "Could not unlink Microsoft integration",
-    "Tenant ID (optional)" : "Tenant ID (optional)",
-    "Domain Match: {provisioningDomain}" : "Domain Match: {provisioningDomain}",
-    "Email: {email}" : "ایمیل: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} on {host}: {port} (رمزگذاری {ssl))",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} on {host}: {port} (رمزگذاری s ssl))",
-    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} on {host}:{port} ({ssl} encryption)",
-    "Configuration for \"{provisioningDomain}\"" : "Configuration for \"{provisioningDomain}\"",
-    "Provisioning domain" : "Provisioning domain",
-    "Email address template" : "Email address template",
-    "IMAP" : "IMAP",
-    "User" : "User",
-    "Host" : "میزبان",
-    "Port" : "درگاه",
-    "SMTP" : "SMTP",
-    "Sieve" : "Sieve",
-    "Enable sieve integration" : "Enable sieve integration",
-    "LDAP aliases integration" : "LDAP aliases integration",
-    "Enable LDAP aliases integration" : "Enable LDAP aliases integration",
-    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases.",
-    "LDAP attribute for aliases" : "LDAP attribute for aliases",
-    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted.",
-    "Save Config" : "Save Config",
-    "Unprovision & Delete Config" : "Unprovision & Delete Config",
-    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% and %EMAIL% will be replaced with the user's UID and email",
-    "With the settings above, the app will create account settings in the following way:" : "با تنظیمات فوق ، برنامه تنظیمات حساب را به روش زیر ایجاد می کند:",
-    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key.",
-    "Failed to import the certificate. Please check the password." : "Failed to import the certificate. Please check the password.",
-    "Certificate imported successfully" : "Certificate imported successfully",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase.",
-    "Failed to import the certificate" : "Failed to import the certificate",
-    "S/MIME certificates" : "S/MIME certificates",
-    "Certificate name" : "Certificate name",
-    "E-mail address" : "آدرس ایمیل",
-    "Valid until" : "متعبر تا",
-    "Delete certificate" : "Delete certificate",
-    "No certificate imported yet" : "No certificate imported yet",
-    "Import certificate" : "Import certificate",
-    "Import S/MIME certificate" : "Import S/MIME certificate",
-    "PKCS #12 Certificate" : "PKCS #12 Certificate",
-    "PEM Certificate" : "PEM Certificate",
-    "Certificate" : "گواهی",
-    "Private key (optional)" : "Private key (optional)",
-    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "The private key is only required if you intend to send signed and encrypted emails using this certificate.",
-    "Submit" : "ارسال",
-    "Account connected" : "Account connected",
-    "You can close this window" : "You can close this window",
-    "Connect your mail account" : "حساب ایمیل خود را وصل کنید",
-    "To add a mail account, please contact your administrator." : "To add a mail account, please contact your administrator.",
     "All" : "همه",
     "Drafts" : "پیش نویس",
     "Favorites" : "علاقه مندی ها",
@@ -610,8 +455,6 @@ OC.L10N.register(
     "Redirect" : "تغییر مسیر",
     "The link leads to %s" : "پیوند منجر به%s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
-    "Continue to %s" : "ادامه دهید%s",
-    "Actions" : "کنش‌ها",
-    "New action" : "New action"
+    "Continue to %s" : "ادامه دهید%s"
 },
 "nplurals=2; plural=(n > 1);");
