@@ -197,50 +197,6 @@ OC.L10N.register(
     "Save signature" : "שמירת החתימה",
     "Tag already exists" : "תגית כבר קיימת",
     "An error occurred, unable to create the tag." : "אירעה שגיאה, לא ניתן ליצור את התגית.",
-    "Add tag" : "הוספת תגית",
-    "Saving tag …" : "התגית נשמרת…",
-    "Could not load your message thread" : "לא ניתן לטעון את שרשור ההודעות שלך",
-    "Not found" : "לא נמצא",
-    "Reply to sender only" : "להגיב לשולח בלבד",
-    "Mark as unread" : "סימון כלא נקרא",
-    "Mark as read" : "סימון כנקרא",
-    "Message source" : "מקור ההודעה",
-    "Could not remove trusted sender {sender}" : "לא ניתן להסיר את השולח המאומת {sender}",
-    "No senders are trusted at the moment." : "אין שולחים מהימנים כרגע.",
-    "Untitled event" : "אירוע ללא כותרת",
-    "(organizer)" : "(מארגן)",
-    "Import into {calendar}" : "ייבוא לתוך {calendar}",
-    "Event imported into {calendar}" : "האירוע ייובא לתוך {calendar}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "טיסה {flightNr} מ{depAirport} אל {arrAirport}",
-    "Airplane" : "מטוב",
-    "Reservation {id}" : "הזמנה {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} מ־{depStation} אל {arrStation}",
-    "Train from {depStation} to {arrStation}" : "רכבת מ־{depStation} אל {arrStation}",
-    "Train" : "רכבת",
-    "matches" : "תואם",
-    "Priority" : "עדיפות",
-    "Mail app" : "יישומון דוא״ל",
-    "The mail app allows users to read mails on their IMAP accounts." : "יישומון הדוא״ל מאפשר למשתמשים לקרוא הודעות דוא״ל בחשבונות ה־IMAP שלהם.",
-    "Reset" : "איפוס",
-    "Client ID" : "מזהה לקו",
-    "Client secret" : "סוד לקוח",
-    "Email: {email}" : "דוא״ל: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP:‏ {user} על גבי ‎{host}:{port}‎ (הצפנת {ssl})",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP:‏ {user} על גבי ‎{host}:{port}‎ (הצפנת {ssl})",
-    "Email address template" : "תבנית כתובת דוא״ל",
-    "IMAP" : "IMAP",
-    "User" : "משתמש",
-    "Host" : "מארח",
-    "Port" : "פתחה",
-    "SMTP" : "SMTP",
-    "Save Config" : "שמירת הגדרות",
-    "With the settings above, the app will create account settings in the following way:" : "עם ההגדרות שלהלן, היישומון יצור הגדרות חשבון באופן הבא:",
-    "E-mail address" : "כתובת דוא״ל",
-    "Valid until" : "בתוקף עד",
-    "Certificate" : "אישור",
-    "Submit" : "שליחה",
-    "Account connected" : "חשבון מחובר",
-    "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
     "All" : "הכול",
     "Drafts" : "טיוטות",
     "Favorites" : "מועדפים",
@@ -266,7 +222,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
     "Redirect" : "הפנייה",
     "The link leads to %s" : "הקישור מוביל אל %s",
-    "Continue to %s" : "ממשיך אל %s",
-    "Actions" : "פעולות"
+    "Continue to %s" : "ממשיך אל %s"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
