@@ -47,18 +47,10 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Etiquettas",
     "Custom" : "Personalisate",
-    "matches" : "corresponde",
-    "Priority" : "Prioritate",
-    "Reset" : "Re-fixar",
-    "User" : "User",
-    "Host" : "Hospite",
-    "Port" : "Porto",
-    "Valid until" : "Valide usque",
     "All" : "Tote",
     "Favorites" : "Favoritos",
     "All inboxes" : "Tote cassas de entrata",
     "Could not load {tag}{name}{endtag}" : "Impossibile cargar {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}",
-    "Actions" : "Actiones"
+    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}"
 },
 "nplurals=2; plural=(n != 1);");
