@@ -78,25 +78,6 @@ OC.L10N.register(
     "Tags" : "Tag",
     "Custom" : "Ubahan",
     "Tag already exists" : "Tag sudah ada",
-    "Add tag" : "Tambahkan tag",
-    "Unsubscribe" : "Berhenti berlangganan",
-    "Mark as unread" : "Tandai belum dibaca",
-    "Mark as read" : "tandai sudah dibaca",
-    "Untitled event" : "Acara tanpa judul",
-    "(organizer)" : "(penyelenggara)",
-    "Operator" : "Operator",
-    "Actions" : "Tindakan",
-    "Allow additional Mail accounts from User Settings" : "Perbolehkan akun Mail tambahan dari Setelan Pengguna",
-    "Reset" : "Setel ulang",
-    "Client ID" : "ID Klien",
-    "Client secret" : "Rahasia klien",
-    "User" : "Pengguna",
-    "Host" : "Host",
-    "Port" : "Port",
-    "Valid until" : "Berlaku sampai",
-    "Certificate" : "Sertifikat",
-    "Account connected" : "Akun terhubung",
-    "Connect your mail account" : "Hubungkan akun surel Anda",
     "All" : "Semua",
     "Drafts" : "Konsep",
     "Favorites" : "Disukai",
