@@ -218,6 +218,7 @@ OC.L10N.register(
     "Custom date and time" : "カスタム日時＆時間",
     "Enter a date" : "日付を入力してください",
     "Choose" : "選択",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["添付ファイルのサイズが 許可された{size}を超えています。代わりにリンクでファイルを共有してください。"],
     "Choose a file to add as attachment" : "添付として追加するファイルを選択",
     "Choose a file to share as a link" : "共有リンクにして送信するファイルを選択",
     "_{count} attachment_::_{count} attachments_" : ["{count} 個の添付ファイル"],
@@ -525,210 +526,6 @@ OC.L10N.register(
     "Tag already exists" : "タグはすでに存在します",
     "Tag name cannot be empty" : "タグ名は空にできません",
     "An error occurred, unable to create the tag." : "エラー:タグを作成できませんでした",
-    "Add default tags" : "デフォルトのタグを追加する",
-    "Add tag" : "タグを追加",
-    "Saving tag …" : "タグを保存中しています...",
-    "Task created" : "タスクを作成しました",
-    "Could not create task" : "タスクを作成はできなかったです",
-    "No calendars with task list support" : "タスクリストをサポートするカレンダーはありません",
-    "Summarizing thread failed." : "スレッドの概要作成が失敗しました",
-    "Could not load your message thread" : "メッセージを読み込めませんでした",
-    "The thread doesn't exist or has been deleted" : "スレッドがありませんまたは削除されています",
-    "Loading thread" : "スレッドを読み込み中",
-    "Not found" : "見つかりませんでした",
-    "Encrypted & verified " : "暗号化済み＆検証済み",
-    "Signature verified" : "署名が検証されました",
-    "Signature unverified " : "署名が未検証です",
-    "This message was encrypted by the sender before it was sent." : "このメッセージは送信前に送信者よって暗号化されました。",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "このメッセージには、検証済みのデジタルS/MIME署名が含まれています。メッセージは送信後に変更されていません。",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "このメッセージには未検証のデジタルS/MIME署名が含まれています。メッセージが送信後に変更されたか、署名者の証明書が信頼されていない可能性があります。",
-    "Reply all" : "全て返信する",
-    "Unsubscribe request sent" : "購読解除リクエストが送信されました",
-    "Could not unsubscribe from mailing list" : "メーリングリストから登録解除できませんでした",
-    "Please wait for the message to load" : "メッセージが読み込まれるまでお待ちください",
-    "Disable reminder" : "リマインダを無効にする",
-    "Unsubscribe" : "購読解除",
-    "Reply to sender only" : "送信者のみに返信",
-    "Mark as unfavorite" : "お気に入りから外す",
-    "Mark as favorite" : "お気に入りにする",
-    "Mark as unread" : "未読にする",
-    "Mark as read" : "既読にする",
-    "Message source" : "メッセージソース",
-    "Unsubscribe via link" : "リンク経由で購読を解除する",
-    "Unsubscribing will stop all messages from the mailing list {sender}" : "リスト{sender}から全ての配信メッセージを停止する",
-    "Send unsubscribe email" : "配信停止メールを送信する",
-    "Unsubscribe via email" : "メールで購読を解除する",
-    "{name} Assistant" : "{name}アシスタント",
-    "Go to latest message" : "最新のメッセージへ移動",
-    "Go to newest message" : "一番新しいメッセージへ移動",
-    "Thread summary" : "スレッドの概要",
-    "Please select languages to translate to and from" : "翻訳する言語を選択してください",
-    "The message could not be translated" : "メッセージは翻訳できませんでした",
-    "Translation copied to clipboard" : "翻訳をクリップボードにコピーしました",
-    "Translation could not be copied" : "翻訳をコピーできませんでした",
-    "Translate message" : "メッセージの翻訳",
-    "Source language to translate from" : "翻訳元の言語",
-    "Translate from" : "原文の言語",
-    "Target language to translate into" : "翻訳先の言語",
-    "Translate to" : "翻訳先",
-    "Translating" : "翻訳する",
-    "Copy translated text" : "翻訳されたテキストをコピー",
-    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "フィールドを空のままにするか、0に設定して、ごみ箱の保持を無効にします。ごみ箱を有効にしてから削除したメールのみ処理されます。",
-    "Could not remove trusted sender {sender}" : "信頼できる送信者 {sender} を削除できませんでした",
-    "No senders are trusted at the moment." : "現在、信頼できる送信者はありません。",
-    "Untitled event" : "無題のイベント",
-    "(organizer)" : "（主催者）",
-    "Import into {calendar}" : "{calendar} へインポート",
-    "Event imported into {calendar}" : "イベントが {calendar} にインポートされました",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{depAirport} から {arrAirport} 行きのフライト番号 {flightNr}",
-    "Airplane" : "飛行機",
-    "Reservation {id}" : "予約ID {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{depStation} から {arrStation} 行きの列車番号 {trainNr}",
-    "Train from {depStation} to {arrStation}" : "{depStation} から {arrStation} 行きの列車",
-    "Train" : "列車",
-    "Delete action" : "アクションを削除",
-    "Flag" : "フラグ",
-    "The stop action ends all processing" : "stop アクションは、すべての処理を終了します",
-    "Recipient" : "受信者",
-    "Delete filter" : "フィルターを削除",
-    "Delete mail filter {filterName}?" : "メールフィルター{filterName}を削除しますか？",
-    "Are you sure to delete the mail filter?" : "メールフィルターを削除してよろしいですか？",
-    "New filter" : "新しいフィルター",
-    "Filter saved" : "フィルターを保存しました",
-    "Could not save filter" : "フィルターを保存できませんでした",
-    "Filter deleted" : "フィルターを削除しました",
-    "Could not delete filter" : "フィルターを削除できませんでした",
-    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "メールの混乱をコントロールしましょう。フィルタを使えば、重要なものに優先順位をつけ、乱雑さを解消できます。",
-    "Filter is active" : "フィルターが有効",
-    "Filter is not active" : "フィルターが無効",
-    "Operator" : "条件",
-    "contains" : "を含む",
-    "matches" : "一致",
-    "Delete test" : "テストを削除",
-    "Update mail filter" : "メールフィルターを更新する",
-    "Filter name" : "フィルター名",
-    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "テストは、Subject（メールの件名）、From（送信者）、To（受信者）などのフィールドを対象として、メールサーバー上の受信メールに適用されます。以下の演算子を使用して、これらのフィールドの条件を定義できます：",
-    "An exact match. The field must be identical to the provided value." : "完全一致。フィールドは提供された値と同一でなければなりません。",
-    "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "部分文字列のマッチ。提供された値がそのフィールドに含まれる場合にマッチする。例えば、「report 」は 「port 」にマッチする。",
-    "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "ワイルドカードを使ったパターン・マッチ。記号 「*」は任意の文字数（ない場合も含む）を表し、「? 」は正確に1文字を表す。例えば、「*report*」は 「Business report 2024 」にマッチする。",
-    "Actions are triggered when the specified tests are true. The following actions are available:" : "アクションは、指定されたテストが真であるときにトリガーされる。以下のアクションが利用可能です：",
-    "Moves the message into a specified folder." : "メッセージを指定したフォルダーに移動します。",
-    "Adds a flag to the message." : "メッセージにフラグを追加する。",
-    "Halts the execution of the filter script. No further filters with will be processed after this action." : "フィルタースクリプトの実行を停止する。この操作の後、それ以降のフィルターは処理されません。",
-    "Priority" : "優先度",
-    "Enable filter" : "フィルターを有効にする",
-    "Save filter" : "フィルターを保存する",
-    "Successfully updated config for \"{domain}\"" : " \"{domain}\"の設定が正常に更新されました",
-    "Error saving config" : "設定の保存中にエラーが発生しました",
-    "Saved config for \"{domain}\"" : "\"{domain}\"の設定を保存しました",
-    "Could not save provisioning setting" : "プロビジョニング設定を保存できませんでした",
-    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} 個のアカウントが正常にプロビジョニングされました。"],
-    "There was an error when provisioning accounts." : "アカウントのプロビジョニング時にエラーが発生しました。",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "{domain}のアカウントが正常に削除され、プロビジョニング解除されました",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "\"{domain}\"のアカウントプロビジョニングを解除と削除すする際にエラーが発生しました。",
-    "Could not save default classification setting" : "デフォルトの分類設定を保存できませんでした",
-    "Mail app" : "メールアプリ",
-    "The mail app allows users to read mails on their IMAP accounts." : "メールアプリで、ユーザーはIMAPアカウントでメールを読むことができます。",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "ここでは、インスタンス全体の設定を確認できます。ユーザー固有の設定は、アプリ自体 (左下隅) にあります。",
-    "Account provisioning" : "アカウントをプロビジョニングする",
-    "A provisioning configuration will provision all accounts with a matching email address." : "プロビジョニング設定では、一致する電子メールアドレスを持つ全てのアカウントがプロビジョニングされます。",
-    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "プロビジョニングドメインフィールドでワイルドカード (*) を使用すると、他の設定と一致しない限り、すべてのユーザに適用される設定が作成されます。",
-    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "プロビジョニングメカニズムでは、ワイルドカードドメイン設定よりも特定のドメイン設定が優先されます。",
-    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "ユーザが別の設定ですでにプロビジョニングされた後に一致する新しい設定が見つかった場合、新しい設定が優先され、ユーザはその設定で再プロビジョニングされます。",
-    "There can only be one configuration per domain and only one wildcard domain configuration." : "ドメインごとに設定できるのは1つだけで、ワイルドカードドメイン設定も1つだけです。",
-    "These settings can be used in conjunction with each other." : "これらの設定は、相互に組み合わせて使用できます。",
-    "If you only want to provision one domain for all users, use the wildcard (*)." : "すべてのユーザーに対して 1 つのドメインのみをプロビジョニングする場合は、ワイルドカード (*) を使用します。",
-    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "この設定は、組織のNextcloudとメールサーバーに同じユーザーバックエンドを使用している場合にのみ意味があります。",
-    "Provisioning Configurations" : "設定をプロビジョニングする",
-    "Add new config" : "新しい設定を追加",
-    "Provision all accounts" : "全てのアカウントをプロビジョニングする",
-    "Allow additional mail accounts" : "追加のメールアカウントを許可する",
-    "Allow additional Mail accounts from User Settings" : "ユーザー設定からメールアカウント追加を許可する",
-    "Enable text processing through LLMs" : "LLMによるテキスト処理を有効にする",
-    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Mailアプリは、設定された大規模言語モデルの助けを借りてユーザーデータを処理し、スレッドの要約、スマート返信、イベントの議題などの支援機能を提供します。",
-    "Enable LLM processing" : "LLM処理を有効にする",
-    "Enable classification by importance by default" : "デフォルトでメールの重要度を仕分けする",
-    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "Mailアプリは、機械学習を利用して受信メールを重要度別に分類できます。この機能はデフォルトで有効になっていますが、ここではデフォルトで無効にできます。個々のユーザーは、自分のアカウントの機能を切り替えることができます。",
-    "Enable classification of important mails by default" : "デフォルトで重要なメールの仕分けを有効化する",
-    "Anti Spam Service" : "スパム対策サービス",
-    "You can set up an anti spam service email address here." : "あなたがスパム対策サービスしたいメールアドレスをここで設定できます",
-    "Any email that is marked as spam will be sent to the anti spam service." : "スパムとしてマークされたメールはすべてスパム対策サービスに送信されます。",
-    "Gmail integration" : "Gmailと統合する",
-    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmailでは、IMAP経由でメールにアクセスすることができます。セキュリティ上の理由から、このアクセスはOAuth 2.0接続、または二要素認証とアプリのパスワードを使用するGoogleアカウントでのみ可能です。",
-    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Google Cloudコンソールで\"Webアプリケーション\"の新しいクライアントIDを登録する必要があります。承認済みリダイレクトURIとしてURL{url}を追加します。",
-    "Microsoft integration" : "Microsoft と統合する",
-    "Successfully set up anti spam email addresses" : "スパム対策メールアドレスの設定が成功しました",
-    "Error saving anti spam email addresses" : "スパム対策報告メールを保存する時エラーがでました",
-    "Successfully deleted anti spam reporting email" : "スパム対策報告メールを正常に削除しました",
-    "Error deleting anti spam reporting email" : "スパム対策報告メールを削除エラー",
-    "Anti Spam" : "アンチスパム",
-    "Add the email address of your anti spam report service here." : "あなたのスパム対策報告サービスするメールアドレスをここに追加してください",
-    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "この設定を使用すると、ユーザーが \"スパムとしてマーク\" をクリックしたときに、スパムレポートサーバーにレポート電子メールが送信されます。",
-    "The original message will be attached as a \"message/rfc822\" attachment." : "元のメッセージは \"message/rfc822\" の形式で添付されます。",
-    "\"Mark as Spam\" Email Address" : "\"スパムメールマークではない\"メールアドレス",
-    "\"Mark Not Junk\" Email Address" : "\"迷惑メールマークではない\"メールアドレス",
-    "Reset" : "リセット",
-    "Google integration configured" : "Google統合が設定されました",
-    "Could not configure Google integration" : "Google 統合の設定はできませんでした",
-    "Google integration unlinked" : "Google統合が解除されました",
-    "Could not unlink Google integration" : "Google 統合のリンクを解除できませんでした",
-    "Client ID" : "クライアント ID",
-    "Client secret" : "クライアントシークレット",
-    "Unlink" : "アンリンク",
-    "Microsoft integration configured" : "Tenant統合が設定されました",
-    "Could not configure Microsoft integration" : "Microsoft統合の設定ができませんでした",
-    "Microsoft integration unlinked" : "Microsoft 統合が解除されました",
-    "Could not unlink Microsoft integration" : "Microsoft 統合のリンクを解除できませんでした",
-    "Tenant ID (optional)" : "テナントID（オプション）",
-    "Domain Match: {provisioningDomain}" : "ドメイン一致:{provisioningDomain}",
-    "Email: {email}" : "メール: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {host}:{port}の{user} ({ssl} 暗号化)",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {host}:{port}の{user} ({ssl} 暗号化)",
-    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "シーブ: {user} on {host}:{port} ({ssl} 暗号化)",
-    "Configuration for \"{provisioningDomain}\"" : " \"{provisioningDomain}\"の設定",
-    "Provisioning domain" : "プロビジョニングドメイン",
-    "Email address template" : "メールアドレステンプレート",
-    "IMAP" : "IMAP",
-    "User" : "ユーザー",
-    "Host" : "ホスト",
-    "Port" : "ポート",
-    "SMTP" : "SMTP",
-    "Master password" : "マスターパスワード",
-    "Use master password" : "マスターパスワードを使用する",
-    "Sieve" : "仕分け",
-    "Enable sieve integration" : "sieve統合を有効にする",
-    "LDAP aliases integration" : "LDAP エイリアスの統合",
-    "Enable LDAP aliases integration" : "LDAPエイリアス統合を有効にする",
-    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAPエイリアス統合は、設定されたLDAPディレクトリから属性を読み取り、電子メールエイリアスをプロビジョニングします。",
-    "LDAP attribute for aliases" : "エイリアスの LDAP 属性",
-    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "電子メールエイリアスをプロビジョニングするためのマルチ値属性。値ごとにエイリアスが作成されます。LDAPディレクトリにないNextcloudに存在するエイリアスは削除されます。",
-    "Save Config" : "設定を保存",
-    "Unprovision & Delete Config" : "プロビジョニング解除と設定の削除",
-    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* USERID%と %E MAIL%は、ユーザーのUIDとEメールに置き換えられます。",
-    "With the settings above, the app will create account settings in the following way:" : "上記の設定では、アプリは次の方法でアカウント設定を作成します：",
-    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "指定されたPKCS#12証明書には、少なくとも一つの証明書と一つの秘密鍵が含まれている必要があります。",
-    "Failed to import the certificate. Please check the password." : "証明書のインポートが失敗しました。パスワードをチェックしてください",
-    "Certificate imported successfully" : "証明書のインポートが成功しました",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "証明書のインポートに失敗しました。秘密鍵が証明書と一致し、パスフレーズで保護されていないことを確認してください。",
-    "Failed to import the certificate" : "証明書のインポートするが失敗した",
-    "S/MIME certificates" : "S/MIME証明書",
-    "Certificate name" : "証明書名",
-    "E-mail address" : "メールアドレス",
-    "Valid until" : "有効期限",
-    "Delete certificate" : "証明書を削除する",
-    "No certificate imported yet" : "証明書はまだインポートされていません",
-    "Import certificate" : "証明書をインポートする",
-    "Import S/MIME certificate" : "S/MIME 証明書をインポートする",
-    "PKCS #12 Certificate" : "PKCS #12 証明書",
-    "PEM Certificate" : "PEM証明書",
-    "Certificate" : "証明",
-    "Private key (optional)" : "秘密鍵（オプション）",
-    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "秘密鍵は、この証明書を使用して署名および暗号化された電子メールを送信する場合にのみ必要です。",
-    "Submit" : "送信",
-    "Account connected" : "アカウント接続済",
-    "You can close this window" : "このウィンドウを閉じることができます",
-    "Connect your mail account" : "あなたのメールアカウントに接続",
-    "To add a mail account, please contact your administrator." : "メールアカウントを追加するためには、あなたの管理者に連絡してください",
     "All" : "すべて",
     "Drafts" : "下書き",
     "Favorites" : "お気に入り",
@@ -764,12 +561,6 @@ OC.L10N.register(
     "Redirect" : "リダイレクト",
     "The link leads to %s" : "リンクが %s につながります",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ページにアクセスしたくない場合は、<a href=\"%s\">メール</a>に戻ることができます",
-    "Continue to %s" : "%s にリダイレクトする",
-    "If all tests pass, then the actions will be executed" : "すべてのテストがパスすれば、アクションが実行されます",
-    "If one test pass, then the actions will be executed" : "テストが1つでもパスすれば、アクションが実行されます",
-    "Tests" : "テスト",
-    "New test" : "新しいテスト",
-    "Actions" : "アクション",
-    "New action" : "新しいアクション"
+    "Continue to %s" : "%s にリダイレクトする"
 },
 "nplurals=1; plural=0;");
