@@ -96,21 +96,6 @@ OC.L10N.register(
     "Tags" : "ტეგები",
     "Select tags" : "აირჩიეთ ტეგები",
     "Custom" : "ინდივიდუალური",
-    "Add tag" : "ტეგის დამატება",
-    "Mark as unread" : "წაუკითხავად მონიშვნა",
-    "Mark as read" : "წაკითხულად მონიშვნა",
-    "Actions" : "მოქმედებები",
-    "Priority" : "პრიორიტეტი",
-    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
-    "Client ID" : "კლიენტის ID",
-    "Client secret" : "კლიენტის საიდუმლო",
-    "User" : "მომხმარებელი",
-    "Host" : "ჰოსტი",
-    "Port" : "პორტი",
-    "Valid until" : "ვარგისია",
-    "Certificate" : "სერტიფიკატი",
-    "Submit" : "გაგზავნა",
-    "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
     "All" : "ყველა",
     "Drafts" : "მონახაზები",
     "Favorites" : "რჩეულები",
