@@ -38,9 +38,6 @@ OC.L10N.register(
     "Add" : "Rnu",
     "Close" : "Mdel",
     "Tags" : "Tibzimin",
-    "Mark as unread" : "Creḍ ur yettwaɣra ara",
-    "Mark as read" : "Creḍ yettwaɣra",
-    "User" : "Aseqdac",
     "All" : "Akk",
     "Favorites" : "Imenyafen",
     "Inbox" : "Tanaka",
