@@ -30,16 +30,12 @@ OC.L10N.register(
     "Close" : "បិទ",
     "Date" : "កាលបរិច្ឆេទ",
     "Tags" : "ស្លាក",
-    "User" : "User",
-    "Host" : "ម៉ាស៊ីន​ផ្ទុក",
-    "Port" : "ច្រក",
     "All" : "ទាំងអស់",
     "Drafts" : "ពង្រាង",
     "Favorites" : "Favorites",
     "Inbox" : "ក្នុង​ប្រអប់សារ",
     "Junk" : "ព្រៃ",
     "Sent" : "ផ្ញើ",
-    "Trash" : "ធុង​សំរាម",
-    "Sending …" : "កំពុង​ផ្ញើរ..."
+    "Trash" : "ធុង​សំរាម"
 },
 "nplurals=1; plural=0;");
