@@ -2,33 +2,40 @@ OC.L10N.register(
     "mail",
     {
     "Personal" : "ສ່ວນບຸກຄົນ",
+    "Mail" : "ຈົດໝາຍ",
+    "Save" : "ບັນທຶກ",
     "Name" : "ຊື່",
     "Password" : "ລະຫັດຜ່ານ",
     "None" : "ບໍ່ມີ",
-    "Save" : "ບັນທຶກ",
     "Change name" : "ປ່ຽນຊື່",
     "Cancel" : "ຍົກເລີກ",
+    "Accounts" : "ບັນຊີ",
+    "General" : "ທົ່ວໄປ",
+    "About" : "ກ່ຽວກັບ",
+    "Delete" : "ລຶບ",
+    "Search" : "ຄົ້ນຫາ",
     "Send" : "ສົ່ງ",
+    "Refresh" : "Refresh",
+    "Choose" : "ເລືອກ",
+    "Confirm" : "ຢືນຢັນ",
     "Unfavorite" : "ລາຍການທີ່ບໍ່ມັກ",
     "Favorite" : "ລາຍການທີ່ມັກ",
-    "Select" : "ເລືອກ",
-    "Move" : "ຍ້າຍ",
-    "Forward" : "ໄປຂ້າງຫນ້າ",
+    "Back" : "ຫຼັງ",
     "Create" : "ສ້າງ",
-    "Choose" : "ເລືອກ",
-    "Show images" : "ສະເເດງຮູບພາບ",
-    "Quota" : "ການໃຊ້ຮ່ວມກັນໄດ້",
-    "Remove account" : "ຍ້າຍບັນຊີ",
-    "Loading …" : "ກຳລັງໂຫຼດ",
-    "Clear cache" : "ລ້າງ Cache ",
-    "Delete" : "ລຶບ",
-    "Add" : "ເພີ່ມ",
-    "Unset" : "ຍົກເລີກການຕັ້ງຄ່າ",
+    "Select" : "ເລືອກ",
     "Remove" : "ຍ້າຍອອກ",
-    "General" : "ທົ່ວໄປ",
-    "User" : "ຜູ້ໃຊ້",
-    "Search" : "ຄົ້ນຫາ",
-    "Refresh" : "Refresh",
+    "Forward" : "ໄປຂ້າງຫນ້າ",
+    "Translate" : "ແປ",
+    "Show images" : "ສະເເດງຮູບພາບ",
+    "Move" : "ຍ້າຍ",
+    "Loading …" : "ກຳລັງໂຫຼດ",
+    "Remove account" : "ຍ້າຍບັນຊີ",
+    "Quota" : "ການໃຊ້ຮ່ວມກັນໄດ້",
+    "Clear cache" : "ລ້າງ Cache ",
+    "Add" : "ເພີ່ມ",
+    "Close" : "ປິດ",
+    "Date" : "ວັນທີ",
+    "Tags" : "ປ້າຍກຳກັບ",
     "Favorites" : "ລາຍການທີ່ມັກ"
 },
 "nplurals=1; plural=0;");
