@@ -124,25 +124,6 @@ OC.L10N.register(
     "Delete tag" : "Izdzēst birku",
     "Tag name is a hidden system tag" : "Birkas nosaukums ir slēpta sistēmas birka",
     "Tag already exists" : "Birka jau pastāv",
-    "Not found" : "Nav atrasts",
-    "Untitled event" : "Nenosaukts notikums",
-    "Recipient" : "Saņēmējs",
-    "Operator" : "Operators",
-    "contains" : "saturs",
-    "matches" : "atbilst",
-    "Priority" : "Prioritāte",
-    "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
-    "Reset" : "Atiestatīt",
-    "Client ID" : "Klienta ID",
-    "User" : "Lietotājs",
-    "Host" : "Resursdators",
-    "Port" : "Ports",
-    "Valid until" : "Derīgs līdz",
-    "Certificate" : "Sertifikāts",
-    "Submit" : "Iesniegt",
-    "Account connected" : "Konts sasaistīts",
-    "You can close this window" : "Šo logu var aizvērt.",
-    "Connect your mail account" : "Pievienot savu e-pasta kontu",
     "All" : "Visi",
     "Drafts" : "Melnraksti",
     "Favorites" : "Izlases vienumi",
@@ -162,7 +143,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "Continue to %s" : "Turpināt %s",
-    "Actions" : "Darbības"
+    "Continue to %s" : "Turpināt %s"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
