@@ -153,6 +153,7 @@ OC.L10N.register(
     "Custom date and time" : "Одреден датум и време",
     "Enter a date" : "Внеси датум",
     "Choose" : "Избери",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Прилогот ја надминува најголемата дозволена големина за прилози од {size}. Споделете го прилогот со линк.","Прилозите ја надминуваат најголемата дозволена големина за прилози од {size}. Споделете ги прилозите со линк."],
     "Choose a file to add as attachment" : "Избери датотека за да додадете прилог",
     "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
     "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилози"],
@@ -346,59 +347,6 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Името на ознаката е сокриена системска ознака",
     "Tag already exists" : "Тагот веќе постои",
     "An error occurred, unable to create the tag." : "Настана грешка, неможе да се креира ознака.",
-    "Add default tags" : "Додади стандардни ознаки",
-    "Add tag" : "Додади ознака",
-    "Saving tag …" : "Зачувување ознака …",
-    "Could not load your message thread" : "Неможат да се преземат информации за пораката",
-    "Not found" : "Не е пронајдено",
-    "Reply all" : "Одговори на сите",
-    "Reply to sender only" : "Одговор само до испраќачот",
-    "Mark as unfavorite" : "Од-означи омилена",
-    "Mark as favorite" : "Означи како омилена",
-    "Mark as unread" : "Означи како непрочитано",
-    "Mark as read" : "Означи како прочитано",
-    "Message source" : "Извор на пораката",
-    "Untitled event" : "Неименуван настан",
-    "(organizer)" : "(organizer)",
-    "Import into {calendar}" : "Увези во {calendar}",
-    "Event imported into {calendar}" : "Настанот е увезен во {calendar}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Лет {flightNr} од {depAirport} до {arrAirport}",
-    "Airplane" : "Авион",
-    "Reservation {id}" : "Резервација {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} од {depStation} до {arrStation}",
-    "Train from {depStation} to {arrStation}" : "Воз од  {depStation} до {arrStation}",
-    "Train" : "Воз",
-    "Flag" : "Знаме",
-    "matches" : "се совпаѓа",
-    "Priority" : "Приоритет",
-    "Mail app" : "Апликација Електронска пошта",
-    "The mail app allows users to read mails on their IMAP accounts." : "Апликацијата за електронска пошта дозволува на корисниците да ги читаат својте пораки од IMAP сметки.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Овде може да се пронајде поопшитно прилагодување. Специфични параметри за корисниците може да се пронајдат во самата апликација (доле-лево).",
-    "Gmail integration" : "Gmail интеграција",
-    "Microsoft integration" : "Microsoft интеграција",
-    "Reset" : "Ресетирање",
-    "Client ID" : "Клиент ИД",
-    "Client secret" : "Тајна на клиент",
-    "Domain Match: {provisioningDomain}" : "Софпаѓање на домен: {provisioningDomain}",
-    "Email: {email}" : "Е-пошта: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} ({ssl} енкрипција)",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} на {host}:{port} ({ssl} енкрипција)",
-    "Configuration for \"{provisioningDomain}\"" : "Конфигурација за \"{provisioningDomain}\"",
-    "IMAP" : "IMAP",
-    "User" : "Корисник",
-    "Host" : "Домаќин",
-    "Port" : "Порта",
-    "SMTP" : "SMTP",
-    "Save Config" : "Зачувај конфигурација",
-    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% и %EMAIL% ќе биде заменето со корнички ID и e-po[ta",
-    "With the settings above, the app will create account settings in the following way:" : "Со овие параметри, апликацијата ќе креира сметки:",
-    "E-mail address" : "Е-пошта адреса",
-    "Valid until" : "Валиден до",
-    "Certificate" : "Сертификат",
-    "Submit" : "Испрати",
-    "Account connected" : "Сметката е поврзана",
-    "You can close this window" : "Можете да го затворите овој прозорец",
-    "Connect your mail account" : "Поврзете ја вашата е-пошта сметка",
     "All" : "Сите",
     "Drafts" : "Шаблони",
     "Favorites" : "Омилени",
@@ -429,8 +377,6 @@ OC.L10N.register(
     "Redirect" : "Пренасочи",
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
-    "Continue to %s" : "Продолжи до %s",
-    "Actions" : "Акции",
-    "New action" : "Нова акција"
+    "Continue to %s" : "Продолжи до %s"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
