@@ -54,9 +54,12 @@ OC.L10N.register(
     "Email address" : "Endereço de email",
     "Add alias" : "Adicionar alcunha",
     "Cancel" : "Cancelar",
+    "Accounts" : "Contas",
     "Add mail account" : "Adicionar conta de email",
     "General" : "Geral",
     "List" : "Lista",
+    "Newest" : "Newest",
+    "Oldest" : "Oldest",
     "Use Gravatar and favicon avatars" : "Usar Gravatar e favicon avatars",
     "Register as application for mail links" : "Registar como aplicação para ligações de correio",
     "Register" : "Registar",
@@ -160,6 +163,7 @@ OC.L10N.register(
     "Retry" : "Repetir",
     "Warning sending your message" : "Aviso ao enviar a sua mensagem",
     "Send anyway" : "Enviar de qualquer maneira",
+    "First day" : "First day",
     "Message" : "Mensagem",
     "Contacts with this address" : "Contactos com este endereço",
     "Add to Contact" : "Adicionar aos contactos",
@@ -173,40 +177,11 @@ OC.L10N.register(
     "Body" : "Corpo",
     "Date" : "Data",
     "Tags" : "Etiquetas",
+    "Last 7 days" : "Últimos 7 dias",
     "Custom" : "Personalizado",
     "Signature …" : "Assinatura...",
     "Save signature" : "Guardar assinatura",
     "Tag already exists" : "A etiqueta já existe",
-    "Not found" : "Não foi encontrado",
-    "Reply to sender only" : "Resposta apenas ao remetente",
-    "Message source" : "Fonte da mensagem",
-    "Import into {calendar}" : "Importar para {calendar}",
-    "Event imported into {calendar}" : "Evento importado para {calendar}",
-    "Airplane" : "Avião",
-    "Reservation {id}" : "Reserva {id}",
-    "Train" : "Comboio",
-    "Recipient" : "Destinatário",
-    "Operator" : "Operador",
-    "contains" : "contém",
-    "matches" : "corresponde",
-    "Filter name" : "Filtrar nome",
-    "Priority" : "Prioridade",
-    "Reset" : "Reiniciar",
-    "Client ID" : "Id. do Cliente",
-    "Client secret" : "Segredo do cliente\\\\",
-    "Email: {email}" : "Email: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} em {host}:{port} ({ssl} encryption)",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} em {host}:{port} ({ssl} encryption)",
-    "IMAP" : "IMAP",
-    "User" : "Utilizador",
-    "Host" : "Anfitrião",
-    "Port" : "Porta",
-    "SMTP" : "SMTP",
-    "Valid until" : "Válido até",
-    "Certificate" : "Certificado",
-    "Submit" : "Submeter",
-    "Account connected" : "Conta ligada",
-    "Connect your mail account" : "Ligue a sua conta de e-mail",
     "All" : "Todos",
     "Drafts" : "Rascunhos",
     "Favorites" : "Favoritos",
@@ -228,8 +203,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redirecionado dentro de segundos.",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
-    "Continue to %s" : "Continuar para %s",
-    "Actions" : "Ações",
-    "New action" : "Nova ação"
+    "Continue to %s" : "Continuar para %s"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
