@@ -212,6 +212,7 @@ OC.L10N.register(
     "Custom date and time" : "Настроить дату и время",
     "Enter a date" : "Выберите дату",
     "Choose" : "Выберите",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Размер этого вложения превышает установленный лимит, который равен {size}. Опубликуйте этот файл с доступом по ссылке и перешлите ссылку, вместо отправки файла.","Размер этих вложений превышает установленный лимит, который равен {size}. Опубликуйте эти файлы с доступом по ссылке и перешлите ссылку, вместо отправки файлов.","Размер этих вложений превышает установленный лимит, который равен {size}. Опубликуйте эти файлы с доступом по ссылке и перешлите ссылку, вместо отправки файлов.","Размер этих вложений превышает установленный лимит, который равен {size}. Опубликуйте эти файлы с доступом по ссылке и перешлите ссылку, вместо отправки файлов."],
     "Choose a file to add as attachment" : "Выбрать файл для вложения",
     "Choose a file to share as a link" : "Выберите файл для публикации ссылкой",
     "_{count} attachment_::_{count} attachments_" : ["{count} вложение","{count} вложения","{count} вложений","{count} вложений"],
@@ -349,6 +350,7 @@ OC.L10N.register(
     "Choose a folder to store the attachments in" : "Выбрать папку для сохранения вложений",
     "Save all to Files" : "Сохранить все в файлы",
     "Download Zip" : "Скачать в архиве ZIP",
+    "_View {count} more attachment_::_View {count} more attachments_" : ["Просмотреть ещё {count} вложение","Просмотреть ещё {count} вложения","Просмотреть остальные вложения ({count})","Просмотреть ещё {count} вложений"],
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Это сообщение зашифровано с помощью PGP. Установите приложение Mailvelope для расшифровывания. ",
     "The images have been blocked to protect your privacy." : "Загрузка изображений заблокирована в целях конфиденциальности.",
     "Show images" : "Показать изображения",
@@ -464,6 +466,7 @@ OC.L10N.register(
     "Select tags" : "Выбор меток",
     "Marked as" : "Отмечено как",
     "Has attachments" : "Имеет вложения",
+    "Has attachment" : "Имеет вложение",
     "Last 7 days" : "Последние 7 дней",
     "From me" : "От меня",
     "Sieve Port" : "Sieve порт",
@@ -487,186 +490,6 @@ OC.L10N.register(
     "Tag already exists" : "Метка уже существует",
     "Tag name cannot be empty" : "Имя тега не может быть пустым",
     "An error occurred, unable to create the tag." : "Не удалось создать метку.",
-    "Add default tags" : "Добавить метки по умолчанию",
-    "Add tag" : "Добавить метку",
-    "Saving tag …" : "Сохранение метки…",
-    "Task created" : "Задача создана",
-    "Could not create task" : "Не удалось создать задачу",
-    "No calendars with task list support" : "Нет календарей с поддержкой списка задач",
-    "Summarizing thread failed." : "Не удалось подвести итоги.",
-    "Could not load your message thread" : "Ошибка загрузки ветки переписки",
-    "The thread doesn't exist or has been deleted" : "Тема не существует или была удалена",
-    "Loading thread" : "Загрузка потока",
-    "Not found" : "Не найдено",
-    "Encrypted & verified " : "Зашифровано и проверено",
-    "Signature verified" : "Подпись проверена",
-    "Signature unverified " : "Подпись не проверена",
-    "This message was encrypted by the sender before it was sent." : "Это сообщение было зашифровано отправителем перед отправкой.",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Это сообщение содержит проверенную цифровую подпись S/MIME. Сообщение не менялось с момента отправки.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Это сообщение содержит непроверенную цифровую подпись S/MIME. Возможно, сообщение было изменено с момента его отправки, или сертификат подписавшего не является доверенным.",
-    "Reply all" : "Ответить всем",
-    "Unsubscribe request sent" : "Запрос на отмену подписки отправлен",
-    "Could not unsubscribe from mailing list" : "Не удалось отписаться от списка рассылки",
-    "Disable reminder" : "Отключить напоминание",
-    "Unsubscribe" : "Отписаться",
-    "Reply to sender only" : "Ответить только отправителю",
-    "Mark as unfavorite" : "Отметить как неизбранное",
-    "Mark as favorite" : "Отметить как избранное",
-    "Mark as unread" : "Отметить не прочитанным",
-    "Mark as read" : "Отметить прочитанным",
-    "Message source" : "Исходный текст сообщения",
-    "Unsubscribe via link" : "Отписаться по ссылке",
-    "Unsubscribing will stop all messages from the mailing list {sender}" : "Отказ от подписки приведет к остановке всех сообщений из списка рассылки {sender}",
-    "Send unsubscribe email" : "Отправить письмо об отказе от подписки",
-    "Unsubscribe via email" : "Отписаться по эл. почте",
-    "{name} Assistant" : "{name} Помощник",
-    "Go to latest message" : "Перейти к последнему сообщению",
-    "Go to newest message" : "Перейти к последнему сообщению",
-    "Thread summary" : "Резюме темы",
-    "The message could not be translated" : "Сообщение не может быть переведено",
-    "Translation copied to clipboard" : "Перевод скопирован в буфер обмена",
-    "Translation could not be copied" : "Не удалось скопировать перевод",
-    "Translate message" : "Перевести сообщение",
-    "Source language to translate from" : "Исходный язык для перевода с",
-    "Translate from" : "Перевод с",
-    "Target language to translate into" : "Целевой язык для перевода на",
-    "Translate to" : "Перевести на",
-    "Translating" : "Идет перевод",
-    "Copy translated text" : "Копировать переведенный текст",
-    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Отключите сохранение корзины, оставив поле пустым или установив для него значение 0. Будут обрабатываться только письма, удаленные после включения сохранения корзины.",
-    "Could not remove trusted sender {sender}" : "Не удалось удалить доверенного отправителя {sender}",
-    "No senders are trusted at the moment." : "Отсутствуют доверенные отправители.",
-    "Untitled event" : "Событие без названия",
-    "(organizer)" : "(организатор)",
-    "Import into {calendar}" : "Импортировать в {calendar}",
-    "Event imported into {calendar}" : "Событие импортировано в «{calendar}»",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Рейс {flightNr} из {depAirport} в {arrAirport}",
-    "Airplane" : "Перелёт",
-    "Reservation {id}" : "Бронирование {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} из {depStation} в {arrStation}",
-    "Train from {depStation} to {arrStation}" : "Поезд из {depStation} в {arrStation}",
-    "Train" : "Поезд",
-    "Flag" : "Флаг",
-    "Recipient" : "Получатель",
-    "Delete filter" : "Удалить фильтр",
-    "New filter" : "Новый фильтр",
-    "Filter deleted" : "Фильтр удалён",
-    "Operator" : "Оператор",
-    "contains" : "содержит",
-    "matches" : "соответствует",
-    "Filter name" : "Имя фильтра",
-    "Priority" : "Приоритет",
-    "Save filter" : "Сохранить фильтр",
-    "Successfully updated config for \"{domain}\"" : "Конфигурация домена «{domain}» обновлена",
-    "Error saving config" : "Не удалось сохранить параметры конфигурации",
-    "Saved config for \"{domain}\"" : "Конфигурация домена «{domain}» сохранена",
-    "Could not save provisioning setting" : "Не удалось сохранить параметры настройки учётных записей",
-    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Успешно подключён {число} аккаунт.","Успешно подключено {число} аккаунтов.","Успешно подключено {число} аккаунтов.","Успешно подключено {count} аккаунтов."],
-    "There was an error when provisioning accounts." : "Не удалось настроить учётные записи",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Успешно удалены и отключены аккаунты для \"{домен}\"",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Возникла ошибка при удалении и отключении аккаунтов для \"{domain}\"",
-    "Could not save default classification setting" : "Не удалось сохранить настройку классификации по умолчанию.",
-    "Mail app" : "Приложение Почта",
-    "The mail app allows users to read mails on their IMAP accounts." : "Приложение Почта позволяет пользователям подключать свои почтовые ящики по протоколу IMAP.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Здесь могут быть заданы параметры, используемые глобально на сервере. Диалог настройки параметров пользователя открывается непосредственно в приложении из значка, расположенного в левом нижнем углу.",
-    "Account provisioning" : "Развёртывание конфигурации",
-    "A provisioning configuration will provision all accounts with a matching email address." : "Развёртывание конфигурации приведёт к настройке параметров всеъ учётных записей с совпадающими  адресами эл. почты.",
-    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "При использовании символа подстановки «*» в поле домена, заданная конфигурация будет применена ко всем пользователям.",
-    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "При настройке учётных записей параметры конфигурации явно заданного домена имеют приоритет перед параметрами, заданными для всех доменов «*».",
-    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "При применении изменённых параметров автоматической настройки, учётные записи пользователей будут перенастроены с учётом новых параметров.",
-    "There can only be one configuration per domain and only one wildcard domain configuration." : "Допускается создание одного набора правил для каждого из доменов и одного общего набора правил.",
-    "These settings can be used in conjunction with each other." : "Общий и доменные наборы правил могут использоваться совместно, дополняя друг друга.",
-    "If you only want to provision one domain for all users, use the wildcard (*)." : "Для настройки учётных записей, если все они расположены в одном домене, используйте символ «*».",
-    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Использовать функцию развёртывания конфигурации почтовых ящиков имеет смысл только в случае, если используется единый механизм управления пользователями Nextcloud и почтового сервера.",
-    "Provisioning Configurations" : "Конфигурация развёртывания",
-    "Add new config" : "Создать параметры конфигурации",
-    "Provision all accounts" : "Настроить все учётные записи",
-    "Allow additional mail accounts" : "Разрешить дополнительные почтовые учетные записи",
-    "Allow additional Mail accounts from User Settings" : "Разрешить дополнительные учетные записи почты в настройках пользователя",
-    "Enable text processing through LLMs" : "Включить обработку текста с помощью LLM",
-    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Приложение «Почта» может обрабатывать пользовательские данные с помощью настроенной большой языковой модели и предоставлять вспомогательные функции, такие как резюме цепочек сообщений, интеллектуальные ответы и повестки событий.",
-    "Enable LLM processing" : "Включить обработку LLM",
-    "Enable classification by importance by default" : "Включить классификацию по важности по умолчанию",
-    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "Приложение Mail может классифицировать входящие электронные письма по важности с помощью машинного обучения. Эта функция включена по умолчанию, но может быть отключена по умолчанию здесь. Отдельные пользователи по прежнему смогут переключать эту функцию для своих учетных записей.",
-    "Enable classification of important mails by default" : "Включить классификацию важных писем по умолчанию",
-    "Anti Spam Service" : "Служба защиты от спама",
-    "You can set up an anti spam service email address here." : "В этом поле возможно задать адрес эл. почты службы анти-спама.",
-    "Any email that is marked as spam will be sent to the anti spam service." : "Все письма, отмеченные как спам, будут отправлены на адрес службы анти-спама.",
-    "Gmail integration" : "Интеграция с Gmail",
-    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail позволяет пользователям получать доступ к своей электронной почте через IMAP. По соображениям безопасности этот доступ возможен только при подключении OAuth 2.0 или учетных записях Google, которые используют двухфакторную аутентификацию и пароли приложений.",
-    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Вам необходимо зарегистрировать новый идентификатор клиента для «веб-приложения» в консоли Google Cloud. Добавьте URL-адрес {url} в качестве URI авторизованного перенаправления.",
-    "Microsoft integration" : "Интеграция с Microsoft",
-    "Successfully set up anti spam email addresses" : "Успешно установлены анти-спам адреса электронной почты",
-    "Error saving anti spam email addresses" : "Ошибка при сохранении анти-спам адресов электронной почты",
-    "Successfully deleted anti spam reporting email" : "Успешно удалён анти-спам адрес отчёта электронной почты",
-    "Error deleting anti spam reporting email" : "Ошибка при удалении анти-спам адреса отчёта электронной почты",
-    "Anti Spam" : "Анти-Спам",
-    "Add the email address of your anti spam report service here." : "Добавьте электронный адрес вашего сервиса отчётов анти-спама сюда.",
-    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "При использовании данной функции, письмо с отчётом будет отправлено на сервер отчётов спама, когда пользователь кликает на \"Пометить как спам\".",
-    "The original message will be attached as a \"message/rfc822\" attachment." : "Исходное письмо будет передано в виде вложения по стандарту message/rfc822\".",
-    "\"Mark as Spam\" Email Address" : "Адрес эл. почты «Пометить как спам»",
-    "\"Mark Not Junk\" Email Address" : "Адрес эл. почты «Пометить не как спам»",
-    "Reset" : "Сброс",
-    "Google integration configured" : "Интеграция с Google настроена",
-    "Could not configure Google integration" : "Не удалось настроить интеграцию с Google",
-    "Google integration unlinked" : "Интеграция с Google отключена",
-    "Could not unlink Google integration" : "Не удалось отменить интеграцию с Google",
-    "Client ID" : "ID клиента",
-    "Client secret" : "Клиентский ключ ",
-    "Unlink" : "Отсоединить",
-    "Microsoft integration configured" : "Интеграция Microsoft настроена",
-    "Could not configure Microsoft integration" : "Не удалось настроить интеграцию Microsoft",
-    "Microsoft integration unlinked" : "Интеграция с Microsoft отключена",
-    "Could not unlink Microsoft integration" : "Не удалось отменить интеграцию Microsoft",
-    "Tenant ID (optional)" : "Идентификатор арендатора (необязательно)",
-    "Domain Match: {provisioningDomain}" : "Соответствует домену: {provisioningDomain}",
-    "Email: {email}" : "Адрес: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на сервере {host}:{port} ({ssl} encryption)",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} на сервере {host}:{port} ({ssl} encryption)",
-    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} на сервере {host}:{port} ({ssl} encryption)",
-    "Configuration for \"{provisioningDomain}\"" : "Параметры автоматической настройки домена «{provisioningDomain}»",
-    "Provisioning domain" : "Имя домена для настройки",
-    "Email address template" : "Шаблон адреса эл. почты",
-    "IMAP" : "IMAP",
-    "User" : "Пользователь",
-    "Host" : "Имя или адрес сервера",
-    "Port" : "Порт",
-    "SMTP" : "SMTP",
-    "Use master password" : "Использовать главный пароль",
-    "Sieve" : "Фильтры Sieve",
-    "Enable sieve integration" : "Использовать поддержку Sieve",
-    "LDAP aliases integration" : "Поддержка псевдонимов LDAP",
-    "Enable LDAP aliases integration" : "Включить поддержку псевдонимов LDAP",
-    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP aliases интеграция считывает атрибут из настроенного LDAP каталога в подключённый адрес электронной почты aliases.",
-    "LDAP attribute for aliases" : "LDAP атрибут для aliases",
-    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Атрибут с несколькими значениями для подключённого адреса электронной почты aliases. Для каждого значения создаётся alias. Все aliase, существующие в Nextcloud, которые не находятся в каталоге LDAP, удаляются.",
-    "Save Config" : "Сохранить параметры конфигурации",
-    "Unprovision & Delete Config" : "Отключить и удалить файл конфигурации",
-    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "*В поля %USERID% and %EMAIL% будут подставлены значения идентификаторов и адресов эл. почты пользователей",
-    "With the settings above, the app will create account settings in the following way:" : "Для настраиваемых учётных записей будут применены следующие параметры:",
-    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Предоставленный сертификат PKCS #12 должен содержать как минимум один сертификат и ровно один закрытый ключ.",
-    "Failed to import the certificate. Please check the password." : "Не удалось импортировать сертификат. Пожалуйста, проверьте пароль.",
-    "Certificate imported successfully" : "Сертификат успешно импортирован",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Не удалось импортировать сертификат. Убедитесь, что закрытый ключ соответствует сертификату и не защищен парольной фразой.",
-    "Failed to import the certificate" : "Не удалось импортировать сертификат",
-    "S/MIME certificates" : "Сертификаты S/MIME",
-    "Certificate name" : "Название сертификата",
-    "E-mail address" : "Адрес эл. почты",
-    "Valid until" : "Дата истечения",
-    "Delete certificate" : "Удалить сертификат",
-    "No certificate imported yet" : "Сертификат еще не импортирован",
-    "Import certificate" : "Импортный сертификат",
-    "Import S/MIME certificate" : "Импортировать сертификат S/MIME",
-    "PKCS #12 Certificate" : "PKCS #12 Сертификат",
-    "PEM Certificate" : "PEM Сертификат",
-    "Certificate" : "Сертификат",
-    "Private key (optional)" : "Закрытый ключ (необязательно)",
-    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Закрытый ключ необходим только в том случае, если вы собираетесь отправлять подписанные и зашифрованные электронные письма с использованием этого сертификата.",
-    "Submit" : "Отправить ответ",
-    "Account connected" : "Аккаунт подключен",
-    "You can close this window" : "Вы можете закрыть это окно",
-    "Connect your mail account" : "Настройка учётной записи электронной почты",
-    "To add a mail account, please contact your administrator." : "Чтобы добавить учетную запись почты, обратитесь к своему администратору.",
     "All" : "Все",
     "Drafts" : "Черновики",
     "Favorites" : "Избранные",
@@ -702,8 +525,6 @@ OC.L10N.register(
     "Redirect" : "Перенаправление",
     "The link leads to %s" : "Эта ссылка ведёт на %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Если вы не хотите посещать эту страницу, вы можете вернуться в <a href=\"%s\">Почту</a>",
-    "Continue to %s" : "Продолжать %s",
-    "Actions" : "Действия",
-    "New action" : "Создать действие"
+    "Continue to %s" : "Продолжать %s"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
