@@ -98,6 +98,7 @@ OC.L10N.register(
     "Encrypt message with Mailvelope" : "Tzifra messàgiu cun Mailvelope",
     "Enter a date" : "Inserta una data",
     "Choose" : "Sèbera",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Is alligongiados propassant sa mannària permìtida de {size}. Cumpartzi is archìvios cun unu ligòngiu.","Is alligongiados propassant sa mannària permìtida de {size}. Cumpartzi is archìvios cun unu ligòngiu."],
     "Choose a file to add as attachment" : "Sèbera un'archìviu de agiùnghere comente alligongiadu",
     "Choose a file to share as a link" : "Sèbera un'archìviu de cumpartzire comente ligòngiu",
     "Confirm" : "Cunfirma",
@@ -255,82 +256,6 @@ OC.L10N.register(
     "Place signature above quoted text" : "Pone sa firma subra su testu tzitadu",
     "Saving new tag name …" : "Sarvende nùmene de eticheta nou...",
     "An error occurred, unable to create the tag." : "B'at àpidu un'errore, no faghet a creare s'eticheta.",
-    "Add tag" : "Agiunghe eticheta",
-    "Saving tag …" : "Sarvende s'eticheta ...",
-    "Could not load your message thread" : "No at fatu a carrigare su messàgiu tuo in sa dibata",
-    "Not found" : "No agatadu",
-    "Unsubscribe" : "Disiscrie·ti",
-    "Reply to sender only" : "Responde isceti a chi at imbiadu",
-    "Mark as unread" : "Marca comente non lèghidu",
-    "Mark as read" : "Marca comente lèghidu",
-    "Message source" : "Fonte de su messàgiu",
-    "Go to newest message" : "Bae a su messàgiu prus nou",
-    "Could not remove trusted sender {sender}" : "No at fatu a nche bogare s'imbiante afidàbile {sender}",
-    "No senders are trusted at the moment." : "No b'at imbiantes afidàbiles in custu momentu.",
-    "Untitled event" : "Eventu chene tìtulu",
-    "(organizer)" : "(persona organizadora)",
-    "Import into {calendar}" : "Importa in {calendar}",
-    "Event imported into {calendar}" : "Eventu importadu in {calendar}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Bolu {flightNr} dae {depAirport} a {arrAirport}",
-    "Airplane" : "Aeroplanu",
-    "Reservation {id}" : "Prenotatzione {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} dae {depStation} a {arrStation}",
-    "Train from {depStation} to {arrStation}" : "Trenu dae {depStation} a {arrStation}",
-    "Train" : "Trenu",
-    "New filter" : "Filtru nou",
-    "matches" : "currispondèntzias",
-    "Priority" : "Prioridade",
-    "Successfully updated config for \"{domain}\"" : "Cunfiguratzione pro \"{domain}\" agiornada in manera curreta",
-    "Error saving config" : "Errore sarvende sa cunfiguratzione",
-    "Saved config for \"{domain}\"" : "Cunfiguratzione pro \"{domain}\" sarvada",
-    "Could not save provisioning setting" : "Impossìbile sarvare sa cunfiguratzione de frunidura",
-    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Frunidura a is {count} contos fata in manera curreta. ","Frunidura a is {count} contos fata in manera curreta. "],
-    "There was an error when provisioning accounts." : "B'at àpidu un'errore in sa frunidura a is contos.",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "S'at cantzelladu e bogadu sa frunidura a is contos pro \"{domain}\"",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errore cantzellende e boghende•nde sa frunidura a is contos pro \"{domain}\"",
-    "Mail app" : "Aplicatzione de posta",
-    "The mail app allows users to read mails on their IMAP accounts." : "S'aplicatzione de posta permitit a is utentes de lèghere is messàgios de is contos IMAP issoro.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Inoghe podes agatare sa cunfiguratzione pro totu s'istàntzia. Is cunfiguratziones ispetzìficas de s'utente sunt in s'aplicatzione etotu (in bàsciu a manca).",
-    "A provisioning configuration will provision all accounts with a matching email address." : "Una cunfiguratzione de frunidura at a frunire a totu is contos un'indiritzu de posta eletrònica currispondente.",
-    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Impreende sa wild card (*) in su campu de domìniu de sa frunidura s'at a creare una cunfiguratzione de aplicare a totu is utentes, frunida a is chi no tenent àtera cunfiguratzione. ",
-    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Su mecanismu de frunidura at a dare prioridade a cunfiguratziones ispetzìficas de domìniu subra de sa cunfiguratzione de domìmiu cun wild card.",
-    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "S'incasu mai s'agatet una cunfiguratzione currispondente noa a pustis chi s'utente aiat giai retzidu un'atera cunfiguratzione, cussa noa at a tènnere pretzedèntzia e s'at a frunire a s'utente a càmbiu de s'àtera.",
-    "There can only be one configuration per domain and only one wildcard domain configuration." : "B'est isceti una cunfiguratzione pro domìniu e isceti una cunfiguratzione de domìniu cun wild card.",
-    "These settings can be used in conjunction with each other." : "Custas optziones s'ant a pòdere impreare in congiuntzione paris sa una cun s'àtera.",
-    "If you only want to provision one domain for all users, use the wildcard (*)." : "S'incasu cheres frunire isceti unu domìniu pro totu is utentes, imprea sa wild card (*).",
-    "Add new config" : "Agiunghe cunfiguratzione noa",
-    "Provision all accounts" : "Fruni a totu is contos",
-    "Reset" : "Ripristina",
-    "Client ID" : "ID cliente",
-    "Client secret" : "Segretu de su cliente",
-    "Domain Match: {provisioningDomain}" : "Currispondèntzia de domìniu: {provisioningDomain}",
-    "Email: {email}" : "Posta eletrònica: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} in {host}:{port} (tzifradura {ssl})",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} in {host}:{port} (tzifradura {ssl})",
-    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} in {host}:{port} (tzifradura {ssl})",
-    "Configuration for \"{provisioningDomain}\"" : "Cunfiguratzione pro \"{provisioningDomain}\"",
-    "Provisioning domain" : "Frunidura de su domìniu",
-    "Email address template" : "Modellu de s'indiritzu de posta eletrònica",
-    "IMAP" : "IMAP",
-    "User" : "Utente",
-    "Host" : "Retzidore",
-    "Port" : "Porta",
-    "SMTP" : "SMTP",
-    "Sieve" : "Sieve",
-    "Enable sieve integration" : "Ativa s'integratzione Sieve",
-    "LDAP aliases integration" : "Integratzione de is identidades LDAP",
-    "Enable LDAP aliases integration" : "Ativa s'integratzione de is identidades LDAP",
-    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "S'integratzione de identidades LDAP leghet un'atributu dae sa cartella LDAP cunfigurada pro sa frunidura de is nomiìngios de posta eletrònica. ",
-    "LDAP attribute for aliases" : "Atributu LDAP pro is identidades",
-    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Un'atributu multi balore pro frunire identidades de posta eletrònica. Pro cada balore si creat un'identidade. Is identidades in Nextcloud chi no sunt in sa cartella LDAP si cantzellant.",
-    "Save Config" : "Sarva cunfiguratzione",
-    "Unprovision & Delete Config" : "Boga•nche sa frunidura e Cantzella Cunfiguratzione",
-    "With the settings above, the app will create account settings in the following way:" : "Cun sa cunfiguratzione de antis, s'aplicatzione at a creare sa cunfiguratzione de contu in custa manera:",
-    "E-mail address" : "Indiritzu de posta eletrònica",
-    "Certificate" : "Tzertificadu",
-    "Submit" : "Imbia",
-    "Account connected" : "Contu collegadu",
-    "Connect your mail account" : "Connete·ti a su contu de posta tuo",
     "All" : "Totu",
     "Drafts" : "Brutacòpias",
     "Favorites" : "Preferidos",
@@ -356,9 +281,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Incarca inoghe chi no ses torradu a deretare in manera automàtica intro de pagu segundos.",
     "Redirect" : "Torra a deretare",
     "The link leads to %s" : "Su ligòngiu deretat a %s",
-    "Continue to %s" : "Sighi in %s",
-    "New test" : "Proa noa",
-    "Actions" : "Atziones",
-    "New action" : "Atzione noa"
+    "Continue to %s" : "Sighi in %s"
 },
 "nplurals=2; plural=(n != 1);");
