@@ -96,21 +96,6 @@ OC.L10N.register(
     "Custom" : "E përshtatur",
     "Delete tag" : "Fshi etiketën",
     "Tag already exists" : "Etiketa ekziston",
-    "Add tag" : "Shto etiketim",
-    "Mark as unread" : "Shënoje si të palexuar",
-    "Mark as read" : "Shënoje si të lexuar",
-    "Actions" : "Veprimet",
-    "Priority" : "Përparësi",
-    "Reset" : "Rivendos",
-    "Client ID" : "ID klienti",
-    "Client secret" : "E fshehtë klienti",
-    "User" : "Përdorues",
-    "Host" : "Strehë",
-    "Port" : "Porta",
-    "Valid until" : "E vlefshme deri më",
-    "Certificate" : "Çertifikata",
-    "Submit" : "Dërgo",
-    "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
     "All" : "Të gjithë",
     "Drafts" : "Skica",
     "Favorites" : "Favorites",
