@@ -18,10 +18,12 @@ OC.L10N.register(
     "General" : "Kuu",
     "Layout" : "Mpangilio",
     "List" : "Orodha",
+    "Register" : "Sajiri",
     "About" : "Kuhusu",
     "Keyboard shortcuts" : "Mikato ya keyboard",
     "Delete" : "Futa",
     "Search" : "Tafuta",
+    "Send" : "Tuma",
     "From" : "Tangu/ kutoka",
     "To" : "Mpaka/ hadi",
     "Choose" : "Chagua",
@@ -34,6 +36,7 @@ OC.L10N.register(
     "This weekend – {timeLocale}" : "Wikendi-{timeLocale}",
     "Next week – {timeLocale}" : "Wiki ijayo-{timeLocale}",
     "Favorite" : "Kipendwa",
+    "Unread" : "Unread",
     "More actions" : "Vitendo zaidi",
     "Back" : "Rudi",
     "Create event" : "Tengeneza matukio",
@@ -45,13 +48,18 @@ OC.L10N.register(
     "Comment" : "Maoni",
     "Accept" : "Kubali",
     "Decline" : "Kataa",
+    "More options" : "Mibadala zaidi",
+    "Remove" : "Ondoa",
     "Other" : "Mengine",
+    "Forward" : "Mbele",
     "Translate" : "Tafsiri",
     "Move" : "Hamisha",
     "Loading …" : "Inapakia",
     "{usage} of {limit} used" : "{usage} ya {limit}imetumika",
+    "Remove account" : "Ondoa akaunti",
     "Rename" : "Ipe jina jipya",
     "Subscribed" : "Iliyojisajili",
+    "Edit message" : "Hariri ujumbe",
     "Reply" : "Jibu",
     "Retry" : "Jaribu tene",
     "Copy to clipboard" : "Nakili kwenye ubao wa kunakili",
@@ -62,20 +70,11 @@ OC.L10N.register(
     "Tags" : "Maoni",
     "Select tags" : "Chagua ukumbusho",
     "Last 7 days" : "Siku 7 zilizopita",
-    "Not found" : "Haipatikani",
-    "Untitled event" : "Tukio lisilotajwa",
-    "(organizer)" : "(Mratibu)",
-    "Priority" : "Kipaumbele",
-    "Reset" : "Pangilia upya",
-    "Client ID" : "Kitambulisho cha mteja",
-    "Client secret" : "Siri ya mteja",
-    "Valid until" : "Halali mpaka",
-    "Submit" : "Wasilisha",
-    "Account connected" : "Akaunti imeunganishwa",
+    "Custom" : "Mteja",
     "All" : "Zote",
     "Favorites" : "Vipendwa",
     "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
-    "Continue to %s" : "Endelea katika %s",
-    "Actions" : "Utendekaji"
+    "Message sent" : "Ujumbe umetumwa",
+    "Continue to %s" : "Endelea katika %s"
 },
 "nplurals=2; plural=(n != 1);");
