@@ -4,34 +4,34 @@ OC.L10N.register(
     "Important" : "முக்கியமான ",
     "Work" : "வேலை",
     "Personal" : "தனிப்பட்ட",
+    "Save" : "சேமிக்க ",
+    "Connect" : "இணைக்க",
     "Name" : "பெயர்",
     "Password" : "கடவுச்சொல்",
     "None" : "ஒன்றுமில்லை",
-    "Save" : "சேமிக்க ",
-    "Connect" : "இணைக்க",
     "Cancel" : "இரத்து செய்க",
-    "Favorite" : "விருப்பமான",
-    "Select" : "Select",
-    "Create" : "உருவாக்குக",
+    "General" : "பொதுவான",
+    "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
+    "Delete" : "நீக்குக",
+    "Search" : "Search",
+    "Refresh" : "மீள் ஏற்றுக",
     "Choose" : "தெரிவுசெய்க ",
+    "Favorite" : "விருப்பமான",
+    "Back" : "பின்னுக்கு",
+    "Description" : "விவரிப்பு",
+    "Create" : "உருவாக்குக",
+    "Select" : "Select",
+    "Remove" : "அகற்றுக",
     "Other" : "மற்றவை",
+    "Translate" : "Translate",
     "Move" : "Move",
     "Quota" : "பங்கு",
     "Saving" : "Saving",
-    "Refresh" : "மீள் ஏற்றுக",
-    "Delete" : "நீக்குக",
+    "Rename" : "பெயர்மாற்றம்",
     "Add" : "சேர்க்க",
     "Close" : "மூடுக",
-    "Tags" : "சீட்டுகள்",
-    "Search" : "Search",
     "Date" : "Date",
-    "Remove" : "அகற்றுக",
-    "General" : "பொதுவான",
-    "User" : "User",
-    "Host" : "ஓம்புனர்",
-    "Port" : "துறை ",
-    "Back" : "பின்னுக்கு",
-    "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
+    "Tags" : "சீட்டுகள்",
     "All" : "எல்லாம்",
     "Favorites" : "விருப்பங்கள்"
 },
