@@ -506,206 +506,6 @@ OC.L10N.register(
     "Tag already exists" : "خەتكۈچ مەۋجۇت",
     "Tag name cannot be empty" : "بەلگە ئىسمى قۇرۇق بولمايدۇ",
     "An error occurred, unable to create the tag." : "خەتكۈچ قۇرالماسلىقتا خاتالىق كۆرۈلدى.",
-    "Add default tags" : "سۈكۈتتىكى بەلگىلەرنى قوشۇڭ",
-    "Add tag" : "خەتكۈچ قوشۇڭ",
-    "Saving tag …" : "خەتكۈچنى ساقلاش…",
-    "Task created" : "ۋەزىپە قۇرۇلدى",
-    "Could not create task" : "ۋەزىپە قۇرالمىدى",
-    "No calendars with task list support" : "ۋەزىپە تىزىملىكى قوللايدىغان كالېندار يوق",
-    "Summarizing thread failed." : "تېمىنى خۇلاسىلەش مەغلۇب بولدى.",
-    "Could not load your message thread" : "ئۇچۇر تېمىڭىزنى يۈكلىيەلمىدى",
-    "The thread doesn't exist or has been deleted" : "بۇ تېما مەۋجۇت ئەمەس ياكى ئۆچۈرۈلگەن",
-    "Loading thread" : "تېما يۈكلەۋاتىدۇ",
-    "Not found" : "تېپىلمىدى",
-    "Encrypted & verified " : "شىفىرلانغان ۋە دەلىللەنگەن ",
-    "Signature verified" : "ئىمزا دەلىللەندى",
-    "Signature unverified " : "ئىمزا دەلىللەنمىگەن ",
-    "This message was encrypted by the sender before it was sent." : "بۇ ئۇچۇر ئەۋەتىشتىن بۇرۇن ئەۋەتكۈچى تەرىپىدىن مەخپىيلەشتۈرۈلگەن.",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "بۇ ئۇچۇردا دەلىللەنگەن رەقەملىك S / MIME ئىمزاسى بار. ئۇچۇر ئەۋەتىلگەندىن بۇيان ئۆزگەرتىلمىگەن.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "بۇ ئۇچۇردا دەلىللەنمىگەن رەقەملىك S / MIME ئىمزاسى بار. ئۇچۇر ئەۋەتىلگەندىن كېيىن ئۆزگەرتىلگەن بولۇشى مۇمكىن ياكى ئىمزا قويغۇچىنىڭ گۇۋاھنامىسى ئىشەنچسىز.",
-    "Reply all" : "ھەممىگە جاۋاب قايتۇرۇڭ",
-    "Unsubscribe request sent" : "ئەۋەتىش ئىلتىماسى ئەۋەتىلدى",
-    "Could not unsubscribe from mailing list" : "خەت ساندۇقىدىن مۇشتەرى بولالمىدى",
-    "Disable reminder" : "ئەسكەرتىشنى چەكلەڭ",
-    "Unsubscribe" : "مۇشتەرى بولۇش",
-    "Reply to sender only" : "ئەۋەتكۈچىگە جاۋاب قايتۇرۇڭ",
-    "Mark as unfavorite" : "ياقتۇرمايدىغان دەپ بەلگە قويۇڭ",
-    "Mark as favorite" : "ياقتۇرىدىغان دەپ بەلگە قويۇڭ",
-    "Mark as unread" : "ئوقۇلمىغان دەپ بەلگە قويۇڭ",
-    "Mark as read" : "ئوقۇغاندەك بەلگە قويۇڭ",
-    "Message source" : "ئۇچۇر مەنبەسى",
-    "Unsubscribe via link" : "ئۇلىنىش ئارقىلىق مۇشتەرى بولۇڭ",
-    "Unsubscribing will stop all messages from the mailing list {sender}" : "مۇشتەرى بولۇش خەت ئەۋەتىش تىزىملىكىدىكى بارلىق ئۇچۇرلارنى توختىتىدۇ {sender}",
-    "Send unsubscribe email" : "مۇشتەرى بولمىغان ئېلېكترونلۇق خەت ئەۋەتىڭ",
-    "Unsubscribe via email" : "ئېلېكترونلۇق خەت ئارقىلىق مۇشتەرى بولۇڭ",
-    "{name} Assistant" : "{name} ياردەمچى",
-    "Go to latest message" : "ئەڭ يېڭى ئۇچۇرغا بېرىڭ",
-    "Go to newest message" : "ئەڭ يېڭى ئۇچۇرغا بېرىڭ",
-    "Thread summary" : "تېما خۇلاسىسى",
-    "The message could not be translated" : "بۇ ئۇچۇرنى تەرجىمە قىلىشقا بولمىدى",
-    "Translation copied to clipboard" : "تەرجىمە تاختىسىغا كۆچۈرۈلگەن",
-    "Translation could not be copied" : "تەرجىمىنى كۆچۈرگىلى بولمىدى",
-    "Translate message" : "ئۇچۇرنى تەرجىمە قىلىڭ",
-    "Source language to translate from" : "تەرجىمە قىلىدىغان مەنبە تىلى",
-    "Translate from" : "دىن تەرجىمە قىلىڭ",
-    "Target language to translate into" : "تەرجىمە قىلىدىغان نىشان تىل",
-    "Translate to" : "تەرجىمە قىلىڭ",
-    "Translating" : "تەرجىمە قىلىش",
-    "Copy translated text" : "تەرجىمە قىلىنغان تېكىستنى كۆچۈرۈڭ",
-    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "مەيداننى قۇرۇق قويۇپ ياكى 0 گە تەڭشەپ ئەخلەت ساندۇقىنى چەكلەشنى چەكلەڭ. ئەخلەت ساندۇقىنى قوزغىتىپ بولغاندىن كېيىن ئۆچۈرۈلگەن خەتلەرلا بىر تەرەپ قىلىنىدۇ.",
-    "Could not remove trusted sender {sender}" : "ئىشەنچلىك ئەۋەتكۈچى {sender} ئۆچۈرەلمىدى",
-    "No senders are trusted at the moment." : "ھازىر ھېچقانداق ئەۋەتكۈچىگە ئىشەنمەيدۇ.",
-    "Untitled event" : "نامسىز ھادىسە",
-    "(organizer)" : "(تەشكىللىگۈچى)",
-    "Import into {calendar}" : "{calendar} ئىمپورت قىلىڭ",
-    "Event imported into {calendar}" : "پائالىيەت {calendar} كىرگۈزۈلگەن",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "ئۇچۇش {flightNr} {depAirport} دىن {arrAirport}",
-    "Airplane" : "ئايروپىلان",
-    "Reservation {id}" : "زاكاس {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} {depStation} دىن {arrStation} غىچە",
-    "Train from {depStation} to {arrStation}" : "{depStation} دىن {arrStation} غا بارىدىغان پويىز",
-    "Train" : "پويىز",
-    "Delete action" : "ھەرىكەتنى ئۆچۈرۈڭ",
-    "Flag" : "بايراق",
-    "The stop action ends all processing" : "توختىتىش ھەرىكىتى بارلىق بىر تەرەپ قىلىشنى ئاخىرلاشتۇرىدۇ",
-    "Delete filter" : "سۈزگۈچنى ئۆچۈرۈڭ",
-    "Delete mail filter {filterName}?" : "خەت سۈزگۈچنى ئۆچۈرۈڭ {filterName}?",
-    "Are you sure to delete the mail filter?" : "خەت سۈزگۈچنى ئۆچۈرەمسىز؟",
-    "New filter" : "يېڭى سۈزگۈچ",
-    "Filter saved" : "سۈزگۈچ ساقلاندى",
-    "Could not save filter" : "سۈزگۈچنى ساقلىيالمىدى",
-    "Filter deleted" : "سۈزگۈچ ئۆچۈرۈلدى",
-    "Could not delete filter" : "سۈزگۈچنى ئۆچۈرەلمىدى",
-    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "ئېلېكترونلۇق خەت قالايمىقانچىلىقىڭىزنى كونترول قىلىڭ. سۈزگۈچلەر مۇھىم ئىشلارنى مۇھىم ئورۇنغا قويۇپ ، قالايمىقانچىلىقنى تۈگىتىشىڭىزگە ياردەم بېرىدۇ.",
-    "Filter is active" : "سۈزگۈچ ئاكتىپ",
-    "Filter is not active" : "سۈزگۈچ ئاكتىپ ئەمەس",
-    "Operator" : "Operator",
-    "contains" : "بار",
-    "matches" : "match",
-    "Delete test" : "سىناقنى ئۆچۈرۈڭ",
-    "Update mail filter" : "خەت سۈزگۈچنى يېڭىلاڭ",
-    "Filter name" : "سۈزگۈچ ئىسمى",
-    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "ئىمتىھان ئېلېكترونلۇق خەت مۇلازىمېتىرىڭىزدىكى كەلگەن ئېلېكترونلۇق خەتلەرگە ، تېما (ئېلېكترونلۇق خەتنىڭ تېما لىنىيىسى) ، (ئەۋەتكۈچى) ۋە (تاپشۇرۇۋالغۇچى) غا ئوخشاش ساھەگە ئىشلىتىلىدۇ. تۆۋەندىكى مەشغۇلاتلارنى ئىشلىتىپ بۇ ساھەنىڭ شەرتلىرىنى بەلگىلىيەلەيسىز:",
-    "An exact match. The field must be identical to the provided value." : "ئېنىق ماس. بۇ ساھە چوقۇم تەمىنلەنگەن قىممەت بىلەن ئوخشاش بولۇشى كېرەك.",
-    "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Subring match. ئەگەر تەمىنلەنگەن قىممەت ئۇنىڭ ئىچىدە بولسا ، مەيدان ماس كېلىدۇ. مەسىلەن ، «دوكلات» «پورت» بىلەن ماس كېلىدۇ.",
-    "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "ياۋايى كارتا ئىشلىتىپ ئەندىزە ماس كېلىدۇ. \"*\" بەلگىسى ھەرپ-بەلگىلەرنى كۆرسىتىدۇ (ھېچقايسىسىنى ئۆز ئىچىگە ئالمايدۇ) ، \"?\" دەل بىر ھەرپكە ۋەكىللىك قىلىدۇ. مەسىلەن ، «* دوكلات *» «سودا دوكلاتى 2024» بىلەن ماس كېلىدۇ.",
-    "Actions are triggered when the specified tests are true. The following actions are available:" : "كۆرسىتىلگەن سىناقلار توغرا بولغاندا ھەرىكەت قوزغىلىدۇ. تۆۋەندىكى ھەرىكەتلەر بار:",
-    "Moves the message into a specified folder." : "ئۇچۇرنى بەلگىلەنگەن قىسقۇچقا يۆتكەيدۇ.",
-    "Adds a flag to the message." : "ئۇچۇرغا بايراق قوشىدۇ.",
-    "Halts the execution of the filter script. No further filters with will be processed after this action." : "سۈزگۈچ قوليازمىسىنىڭ ئىجرا قىلىنىشىنى توختىتىدۇ. بۇ ھەرىكەتتىن كېيىن باشقا سۈزگۈچلەر بىر تەرەپ قىلىنمايدۇ.",
-    "Priority" : "ھەممىدىن مۇھىم",
-    "Enable filter" : "سۈزگۈچنى قوزغىتىڭ",
-    "Save filter" : "سۈزگۈچنى ساقلاڭ",
-    "Successfully updated config for \"{domain}\"" : "\"{domain}\" ئۈچۈن مۇۋەپپەقىيەتلىك يېڭىلاندى.",
-    "Error saving config" : "سەپلىمە خاتا",
-    "Saved config for \"{domain}\"" : "\"{domain}\" ئۈچۈن ساقلانغان سەپلىمە",
-    "Could not save provisioning setting" : "تەمىنلەش تەڭشىكىنى ساقلىيالمىدى",
-    "There was an error when provisioning accounts." : "ھېسابات تەمىنلىگەندە خاتالىق كۆرۈلدى.",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "\"{domain}\" نىڭ ھېساباتلىرى مۇۋەپپەقىيەتلىك ئۆچۈرۈلدى ۋە ئەمەلدىن قالدۇرۇلدى.",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "\"{domain}\" ھېساباتلىرىنى ئۆچۈرۈش ۋە رەتلەشتە خاتالىق",
-    "Could not save default classification setting" : "سۈكۈتتىكى تۈرگە ئايرىشنى ساقلىيالمىدى",
-    "Mail app" : "خەت ئەپى",
-    "The mail app allows users to read mails on their IMAP accounts." : "خەت ئەپى ئابونتلارنىڭ IMAP ھېساباتىدىكى خەتلەرنى ئوقۇيالايدۇ.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "بۇ يەردىن مىسال تەڭشەكلىرىنى تاپالايسىز. ئىشلەتكۈچىنىڭ ئالاھىدە تەڭشىكى ئەپنىڭ ئۆزىدە (سول تەرەپ سول تەرەپ).",
-    "Account provisioning" : "ھېسابات بىلەن تەمىنلەش",
-    "A provisioning configuration will provision all accounts with a matching email address." : "تەمىنات سەپلىمىسى بارلىق ھېساباتلارنى ماس كېلىدىغان ئېلېكترونلۇق خەت ئادرېسى بىلەن تەمىنلەيدۇ.",
-    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "تەمىنلىگۈچى دائىرە رايونىدا ياۋا كارتا (*) نى ئىشلىتىپ ، باشقا سەپلىمىگە ماس كەلمىسە ، بارلىق ئىشلەتكۈچىلەرگە ماس كېلىدىغان سەپلىمە ھاسىل قىلىدۇ.",
-    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "تەمىنلەش مېخانىزمى ياۋايى كارتا دائىرە سەپلىمىسىدىن ئالاھىدە دائىرە سەپلىمىسىنى ئالدىنقى ئورۇنغا قويىدۇ.",
-    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "ئىشلەتكۈچى ئاللىقاچان باشقا سەپلىمە بىلەن تەمىنلەنگەندىن كېيىن يېڭى ماس كېلىدىغان سەپلىمە تېپىلسا ، يېڭى سەپلىمە ئالدىنقى ئورۇنغا قويۇلۇپ ، ئىشلەتكۈچى سەپلىمىسى بىلەن قايتا تۈزىتىلىدۇ.",
-    "There can only be one configuration per domain and only one wildcard domain configuration." : "ھەر بىر دائىرە ئىچىدە پەقەت بىرلا سەپلىمە بولىدۇ ، پەقەت بىرلا ياۋا كارتا دائىرە سەپلىمىسى بولىدۇ.",
-    "These settings can be used in conjunction with each other." : "بۇ تەڭشەكلەرنى ئۆز-ئارا بىرلەشتۈرۈپ ئىشلىتىشكە بولىدۇ.",
-    "If you only want to provision one domain for all users, use the wildcard (*)." : "ئەگەر بارلىق ئىشلەتكۈچىلەر ئۈچۈن پەقەت بىرلا تور نامىنى تەمىنلىمەكچى بولسىڭىز ، ياۋايى كارتا (*) نى ئىشلىتىڭ.",
-    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "ئەگەر بۇ تەشكىلاتنىڭ Nextcloud ۋە ئېلخەت مۇلازىمېتىرىڭىزغا ئوخشاش ئىشلەتكۈچىنىڭ ئارقا تەرىپىنى ئىشلەتسىڭىز ، بۇ تەڭشەك ئەڭ ئەقىلگە مۇۋاپىق.",
-    "Provisioning Configurations" : "سەپلىمىنى تەمىنلەش",
-    "Add new config" : "يېڭى سەپلىمە قوشۇڭ",
-    "Provision all accounts" : "بارلىق ھېساباتلارنى تەمىنلەڭ",
-    "Allow additional mail accounts" : "قوشۇمچە خەت ھېساباتىغا يول قويۇڭ",
-    "Allow additional Mail accounts from User Settings" : "ئىشلەتكۈچى تەڭشەكلىرىدىن قوشۇمچە خەت ھېساباتىغا يول قويۇڭ",
-    "Enable text processing through LLMs" : "LLM ئارقىلىق تېكىست بىر تەرەپ قىلىشنى قوزغىتىڭ",
-    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "خەت ئەپى سەپلەنگەن چوڭ تىل ئەندىزىسىنىڭ ياردىمىدە ئىشلەتكۈچى سانلىق مەلۇماتلىرىنى بىر تەرەپ قىلالايدۇ ۋە تېما خۇلاسىسى ، ئەقلىي جاۋاب ۋە پائالىيەت كۈن تەرتىپى قاتارلىق ياردەم ئىقتىدارلىرى بىلەن تەمىنلەيدۇ.",
-    "Enable LLM processing" : "LLM بىر تەرەپ قىلىشنى قوزغىتىڭ",
-    "Enable classification by importance by default" : "كۆڭۈلدىكى قىممىتى بويىچە تۈرگە ئايرىشنى قوزغىتىڭ",
-    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "خەت ئەپى كەلگەن ئېلېكترونلۇق خەتلەرنى ماشىنا ئۆگىنىشى ئارقىلىق مۇھىم ئورۇنغا ئايرىيالايدۇ. بۇ ئىقتىدار سۈكۈتتىكى ھالەتتە قوزغىتىلغان ، ئەمما بۇ يەردە سۈكۈتتىكى ھالەتتە چەكلىگىلى بولىدۇ. يەككە ئىشلەتكۈچىلەر يەنىلا ھېساباتىدىكى ئىقتىدارنى ئالماشتۇرالايدۇ.",
-    "Enable classification of important mails by default" : "سۈكۈتتىكى مۇھىم خەتلەرنى تۈرگە ئايرىشنى قوزغىتىڭ",
-    "Anti Spam Service" : "ئەخلەت خەتكە قارشى تۇرۇش مۇلازىمىتى",
-    "You can set up an anti spam service email address here." : "سىز بۇ يەردىن ئەخلەت خەتكە قارشى مۇلازىمەت ئېلېكترونلۇق خەت ئادرېسىنى قۇرالايسىز.",
-    "Any email that is marked as spam will be sent to the anti spam service." : "ئەخلەت خەت دەپ بەلگە قويۇلغان ھەر قانداق ئېلېكترونلۇق خەت ئەخلەت خەتكە قارشى تۇرۇش مۇلازىمىتىگە ئەۋەتىلىدۇ.",
-    "Gmail integration" : "Gmail بىرلەشتۈرۈش",
-    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail ئابونتلارنىڭ ئېلېكترونلۇق خەتلىرىنى IMAP ئارقىلىق زىيارەت قىلالايدۇ. بىخەتەرلىك سەۋەبىدىن بۇ زىيارەت پەقەت OAuth 2.0 ئۇلىنىشى ياكى ئىككى ئامىللىق دەلىللەش ۋە ئەپ مەخپىي نومۇرىنى ئىشلىتىدىغان Google ھېساباتى بىلەنلا مۇمكىن.",
-    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Google Cloud كونترول سۇپىسىدا «تور قوللىنىشچان پروگراممىسى» ئۈچۈن يېڭى خېرىدار كىملىكىنى تىزىملىتىشىڭىز كېرەك. ھوقۇق بېرىلگەن قايتا نىشانلانغان URI سۈپىتىدە URL {url} نى قوشۇڭ.",
-    "Microsoft integration" : "مىكروسوفتنىڭ بىر گەۋدىلىشىشى",
-    "Successfully set up anti spam email addresses" : "ئەخلەت خەتكە قارشى ئېلېكترونلۇق خەت ئادرېسىنى مۇۋەپپەقىيەتلىك ئورنىتىڭ",
-    "Error saving anti spam email addresses" : "ئەخلەت خەتكە قارشى ئېلېكترونلۇق خەت ئادرېسىنى ساقلاشتا خاتالىق",
-    "Successfully deleted anti spam reporting email" : "ئەخلەت خەتكە قارشى ئېلېكترونلۇق خەتنى مۇۋەپپەقىيەتلىك ئۆچۈردى",
-    "Error deleting anti spam reporting email" : "ئەخلەت خەتكە قارشى ئېلېكترونلۇق خەتنى ئۆچۈرۈشتە خاتالىق",
-    "Anti Spam" : "ئەخلەت خەتكە قارشى تۇرۇش",
-    "Add the email address of your anti spam report service here." : "ئەخلەت خەتكە قارشى تۇرۇش مۇلازىمىتىڭىزنىڭ ئېلېكترونلۇق خەت ئادرېسىنى بۇ يەرگە قوشۇڭ.",
-    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "بۇ تەڭشەكنى ئىشلەتكەندە ، ئىشلەتكۈچى «ئەخلەت خەت دەپ بەلگە» نى چەككەندە ، ئېلېكترونلۇق خەت SPAM دوكلات مۇلازىمېتىرىغا ئەۋەتىلىدۇ.",
-    "The original message will be attached as a \"message/rfc822\" attachment." : "ئەسلى ئۇچۇر «ئۇچۇر / rfc822» قوشۇمچە قىلىپ باغلىنىدۇ.",
-    "\"Mark as Spam\" Email Address" : "«ئەخلەت خەت دەپ بەلگە» ئېلېكترونلۇق خەت ئادرېسى",
-    "\"Mark Not Junk\" Email Address" : "«ئەخلەت ئەمەس بەلگە» ئېلېكترونلۇق خەت ئادرېسى",
-    "Reset" : "ئەسلىگە قايتۇرۇش",
-    "Google integration configured" : "Google بىرلەشتۈرۈلدى",
-    "Could not configure Google integration" : "Google بىرلەشتۈرۈشنى تەڭشىيەلمىدى",
-    "Google integration unlinked" : "گۇگۇلنىڭ بىر گەۋدىلەشتۈرۈلمىگەن",
-    "Could not unlink Google integration" : "گۇگۇلنىڭ بىر گەۋدىلىشىشىنى ئاچالمىدى",
-    "Client ID" : "Client ID",
-    "Client secret" : "Client secret",
-    "Unlink" : "Unlink",
-    "Microsoft integration configured" : "Microsoft بىر گەۋدىلەشتۈرۈلگەن",
-    "Could not configure Microsoft integration" : "Microsoft بىرلەشتۈرۈشنى تەڭشىيەلمىدى",
-    "Microsoft integration unlinked" : "مىكروسوفتنىڭ بىر گەۋدىلەشتۈرۈلمىگەن",
-    "Could not unlink Microsoft integration" : "مىكروسوفتنىڭ بىر گەۋدىلىشىشىنى ئاچالمىدى",
-    "Tenant ID (optional)" : "ئىجارە ئالغۇچىنىڭ كىملىكى (ئىختىيارىي)",
-    "Domain Match: {provisioningDomain}" : "دائىرە مۇسابىقىسى: {provisioningDomain}",
-    "Email: {email}" : "ئېلخەت: {email}",
-    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} {host}: {port} ({ssl} مەخپىيلەشتۈرۈش)",
-    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} دىكى {host}: {port} ({ssl} مەخپىيلەشتۈرۈش)",
-    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "ئەلگەك: {user} دىكى {host}: {port} ({ssl} مەخپىيلەشتۈرۈش)",
-    "Configuration for \"{provisioningDomain}\"" : "\"{provisioningDomain}\" نىڭ سەپلىمىسى",
-    "Provisioning domain" : "دائىرە بىلەن تەمىنلەش",
-    "Email address template" : "ئېلېكترونلۇق خەت ئادرېسى قېلىپى",
-    "IMAP" : "IMAP",
-    "User" : "User",
-    "Host" : "باش ئاپپارات",
-    "Port" : "ئېغىز",
-    "SMTP" : "SMTP",
-    "Master password" : "ئاساسىي پارول",
-    "Use master password" : "ئاساسىي پارول ئىشلىتىڭ",
-    "Sieve" : "Sieve",
-    "Enable sieve integration" : "ئەلگەك بىرلەشتۈرۈشنى قوزغىتىڭ",
-    "LDAP aliases integration" : "LDAP بىرلەشتۈرۈشنى ئۆزگەرتىدۇ",
-    "Enable LDAP aliases integration" : "LDAP تاشقى پىلانېت بىرلەشتۈرۈشنى قوزغىتىڭ",
-    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP ئۆزگەرتىلگەن بىرىكمە سەپلىمە LDAP مۇندەرىجىسىدىن ئېلېكترونلۇق خەت ئادرېسى بىلەن تەمىنلەيدىغان خاسلىقنى ئوقۇيدۇ.",
-    "LDAP attribute for aliases" : "LDAP خاسلىقى",
-    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "ئېلېكترونلۇق خەت ئادرېسى بىلەن تەمىنلەيدىغان كۆپ خىل قىممەت خاسلىقى. ھەر بىر قىممەت ئۈچۈن بىر تەخەللۇس قۇرۇلدى. Nextcloud دا بار بولغان LDAP مۇندەرىجىسىدە يوق.",
-    "Save Config" : "Save Config",
-    "Unprovision & Delete Config" : "Unprovision & Delete Config",
-    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "*% USERID% ۋە% EMAIL% ئىشلەتكۈچىنىڭ UID ۋە ئېلېكترونلۇق خەت ساندۇقىنىڭ ئورنىنى ئالىدۇ",
-    "With the settings above, the app will create account settings in the following way:" : "يۇقىرىدىكى تەڭشەكلەر بىلەن بۇ دېتال تۆۋەندىكى ئۇسۇلدا ھېسابات تەڭشىكى قۇرىدۇ:",
-    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "تەمىنلەنگەن PKCS # 12 گۇۋاھنامىسىدە كەم دېگەندە بىر گۇۋاھنامە ۋە ئېنىق بىر شەخسىي ئاچقۇچ بولۇشى كېرەك.",
-    "Failed to import the certificate. Please check the password." : "گۇۋاھنامىنى ئەكىرىش مەغلۇب بولدى. پارولنى تەكشۈرۈپ بېقىڭ.",
-    "Certificate imported successfully" : "مۇۋەپپەقىيەتلىك ئىمپورت قىلىنغان گۇۋاھنامە",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "گۇۋاھنامىنى ئەكىرىش مەغلۇب بولدى. شەخسىي ئاچقۇچنىڭ گۇۋاھنامىگە ماس كېلىدىغانلىقى ۋە ئىم بىلەن قوغدالمىغانلىقىغا كاپالەتلىك قىلىڭ.",
-    "Failed to import the certificate" : "گۇۋاھنامىنى ئەكىرىش مەغلۇب بولدى",
-    "S/MIME certificates" : "S / MIME گۇۋاھنامىسى",
-    "Certificate name" : "گۇۋاھنامە ئىسمى",
-    "E-mail address" : "ئېلېكترونلۇق خەت ئادرېسى",
-    "Valid until" : "كۈچكە ئىگە",
-    "Delete certificate" : "گۇۋاھنامىنى ئۆچۈرۈڭ",
-    "No certificate imported yet" : "تېخى ئىمپورت قىلىنغان گۇۋاھنامە يوق",
-    "Import certificate" : "گۇۋاھنامە ئەكىرىش",
-    "Import S/MIME certificate" : "S / MIME گۇۋاھنامىسىنى ئەكىرىڭ",
-    "PKCS #12 Certificate" : "PKCS # 12 گۇۋاھنامىسى",
-    "PEM Certificate" : "PEM گۇۋاھنامىسى",
-    "Certificate" : "گۇۋاھنامە",
-    "Private key (optional)" : "شەخسىي ئاچقۇچ (ئىختىيارى)",
-    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "ئەگەر بۇ گۇۋاھنامە ئارقىلىق ئىمزا قويۇلغان ۋە مەخپىيلەشتۈرۈلگەن ئېلېكترونلۇق خەت ئەۋەتمەكچى بولسىڭىز ، شەخسىي ئاچقۇچ تەلەپ قىلىنىدۇ.",
-    "Submit" : "يوللاڭ",
-    "Account connected" : "ھېسابات ئۇلاندى",
-    "You can close this window" : "بۇ كۆزنەكنى ياپالايسىز",
-    "Connect your mail account" : "خەت ساندۇقىڭىزنى ئۇلاڭ",
-    "To add a mail account, please contact your administrator." : "خەت ھېساباتى قوشۇش ئۈچۈن باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
     "All" : "ھەممىسى",
     "Drafts" : "Drafts",
     "Favorites" : "يىغقۇچ",
@@ -740,12 +540,6 @@ OC.L10N.register(
     "Redirect" : "قايتا نىشانلاش",
     "The link leads to %s" : "ئۇلىنىش% s نى كەلتۈرۈپ چىقىرىدۇ",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ئەگەر ئۇ بەتنى زىيارەت قىلىشنى خالىمىسىڭىز ، <a href = \"% s\"> خەت </a> گە قايتسىڭىز بولىدۇ.",
-    "Continue to %s" : "داۋاملىق% s",
-    "If all tests pass, then the actions will be executed" : "ئەگەر بارلىق سىناقلار ئۆتۈپ كەتسە ، ھەرىكەتلەر ئىجرا بولىدۇ",
-    "If one test pass, then the actions will be executed" : "ئەگەر بىر سىناقتىن ئۆتسە ، ئۇنداقتا ھەرىكەت ئىجرا بولىدۇ",
-    "Tests" : "سىناق",
-    "New test" : "يېڭى سىناق",
-    "Actions" : "مەشغۇلاتلار",
-    "New action" : "يېڭى ھەرىكەت"
+    "Continue to %s" : "داۋاملىق% s"
 },
 "nplurals=2; plural=(n != 1);");
