@@ -186,6 +186,7 @@ OC.L10N.register(
     "Custom date and time" : "Власна дата та час",
     "Enter a date" : "Введіть дату",
     "Choose" : "Вибрати",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Вкладення перевищує дозволений розмір {size}. Рекомендуємо замість цього поділітися файлами через посилання.","Вкладення перевищують дозволений розмір {size}. Рекомендуємо замість цього поділітися файлами через посилання.","Вкладення перевищують дозволений розмір {size}. Рекомендуємо замість цього поділітися файлами через посилання.","Вкладення перевищують дозволений розмір {size}. Рекомендуємо замість цього поділітися файлами через посилання."],
     "Choose a file to add as attachment" : "Виберіть файл для вкладення",
     "Choose a file to share as a link" : "Виберіть файл, яким ви поділитеся через посилання",
     "_{count} attachment_::_{count} attachments_" : ["{count} долучений файл","{count} долучені файли","{count} долучених файлів","{count} долучених файлів"],
@@ -457,91 +458,6 @@ OC.L10N.register(
     "Tag already exists" : "Мітка вже існує",
     "Tag name cannot be empty" : "Назва мітки не може бути порожньою",
     "An error occurred, unable to create the tag." : "Сталася помилка. Неможливо створити мітку.",
-    "Add default tags" : "Додати типові мітки",
-    "Add tag" : "Додати мітку",
-    "Saving tag …" : "Збереження мітки ...",
-    "Task created" : "Завдання створено",
-    "Could not create task" : "Не вдалося створити завдання",
-    "No calendars with task list support" : "Відсутні календарі з підтримкою списку завдань",
-    "Could not load your message thread" : "Не вдалось завантажити ваш ланцюжок повідомлень",
-    "The thread doesn't exist or has been deleted" : "Ланцюжок відсутній або його було вилучено",
-    "Loading thread" : "Завантаження ланцюжка",
-    "Not found" : "Не знайдено",
-    "Encrypted & verified " : "Зашифровано та перевірено",
-    "Signature verified" : "Підпис перевірено",
-    "Signature unverified " : "Підпис не перевірено",
-    "This message was encrypted by the sender before it was sent." : "Це повідомлення було зашифровано відправником перед тим, як його надіслати.",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Це повідомлення містить перевірений цифровий підпис S/MIME. Повідомлення не змінювалося з моменту його надсилання.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Це повідомлення містить неперевірений цифровий підпис S/MIME. Повідомлення могло бути змінено після надсилання або сертифікат підписувача недовірений.",
-    "Reply all" : "Відповісти всім",
-    "Unsubscribe request sent" : "Надіслано запит щодо відписування",
-    "Could not unsubscribe from mailing list" : "Не вдалося відписатися від списку розсилки",
-    "Unsubscribe" : "Відписатися",
-    "Reply to sender only" : "Відповісти лише відправникові",
-    "Mark as unfavorite" : "Прибрати зірочку",
-    "Mark as favorite" : "Позначити зірочкою",
-    "Mark as unread" : "Позначити не прочитаним",
-    "Mark as read" : "Позначити прочитаним",
-    "Message source" : "Джерело повідомлення",
-    "Unsubscribe via link" : "Відписатися через посилання",
-    "Send unsubscribe email" : "Надіслати електронний лист щодо відписування",
-    "Unsubscribe via email" : "Відпусатися через ел.пошту",
-    "{name} Assistant" : "Асистент {name}",
-    "Go to latest message" : "Перейти до останнього повідомлення",
-    "Go to newest message" : "Перейти до найновішого повідомлення",
-    "Translate from" : "Перекласти з",
-    "Translate to" : "Перекласти",
-    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Вимкніть зберігання кошика, для цього залиште поле порожнім або встановіть його значення у 0. Це буде застосовано лише до листів, які було вилучено після увімкнення зберігання кошика.",
-    "Could not remove trusted sender {sender}" : "Не вдалося вилучити довіреного відправника {sender}",
-    "No senders are trusted at the moment." : "Наразі відсутні довірені відправники.",
-    "Untitled event" : "Подія без назви",
-    "(organizer)" : "(організатор)",
-    "Import into {calendar}" : "Імпортувати до {calendar}",
-    "Event imported into {calendar}" : "Подію імпортовано до {calendar}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Рейс {flightNr} з {depAirport} до {arrAirport}",
-    "Airplane" : "Літак",
-    "Reservation {id}" : "Бронювання {id}",
-    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} від {depStation} до {arrStation}",
-    "Train from {depStation} to {arrStation}" : "Потяг з {depStation} до {arrStation}",
-    "Train" : "Потяг",
-    "Delete filter" : "Вилучити фільтр",
-    "Operator" : "Оператор",
-    "contains" : "містить",
-    "matches" : "містить",
-    "Priority" : "Пріоритет",
-    "Mail app" : "Електронна пошта",
-    "The mail app allows users to read mails on their IMAP accounts." : "Застосунок пошти дозволяє користувачам переглядати з їхніх облікових записів IMAP.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Тут ви можете знайти налаштування для всього примірника хмари. Налаштування користувача розташовані у застосунку (див. у лівому нижньому куті).",
-    "Account provisioning" : "Автоматичне налаштування облікового запису",
-    "A provisioning configuration will provision all accounts with a matching email address." : "За допомогою автоматичного налаштування буде налаштовано всі електронні скриньки з відповідними ел. адресами.",
-    "Add new config" : "Додати нову конфігурацію",
-    "Allow additional Mail accounts from User Settings" : "Дозволити додаткові налаштування поштових облікових записів у налаштуваннях користувача",
-    "Gmail integration" : "Інтеграція з Gmail",
-    "Microsoft integration" : "Інтеграція з Microsoft",
-    "Anti Spam" : "Антиспам",
-    "Reset" : "Скидання",
-    "Google integration configured" : "Інтеграцію з Google налаштовано",
-    "Client ID" : "Ідентифікатор клієнта",
-    "Client secret" : "Ключ клієнта",
-    "Microsoft integration unlinked" : "Інтеграцію з Microsoft відключено",
-    "Email: {email}" : "Ел.пошта: {email}",
-    "Email address template" : "Шаблон адреси електронної пошти",
-    "IMAP" : "IMAP",
-    "User" : "Користувач",
-    "Host" : "Хост",
-    "Port" : "Порт",
-    "SMTP" : "SMTP",
-    "Certificate imported successfully" : "Сертифікат успішно імпортовано",
-    "E-mail address" : "Електронна адреса",
-    "Valid until" : "Дійсно до",
-    "Delete certificate" : "Видалити сертифікат",
-    "Certificate" : "Сертифікат",
-    "Private key (optional)" : "Приватний ключ (необов'язково)",
-    "Submit" : "Гаразд",
-    "Account connected" : "Обліковий запис під’єднано",
-    "You can close this window" : "Ви можете закрити це вікно",
-    "Connect your mail account" : "Під'єднати вашу поштову скриньку",
-    "To add a mail account, please contact your administrator." : "Щоби додати поштову скриньку, будь ласка, зверніться до адміністратора",
     "All" : "Всі",
     "Drafts" : "Чернетки",
     "Favorites" : "Із зірочкою",
@@ -568,8 +484,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Натисніть тут, якщо вас не буде автоматично перенаправлено протягом наступних кількох секунд.",
     "Redirect" : "Перенаправлення",
     "The link leads to %s" : "Посилання веде до %s",
-    "Continue to %s" : "Перейти до %s",
-    "Actions" : "Дії",
-    "New action" : "Нова дія"
+    "Continue to %s" : "Перейти до %s"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
