@@ -504,7 +504,12 @@ class ImapMessageFetcher {
 		if ($utf8 !== false) {
 			return $utf8;
 		}
-		return iconv('UTF-8', 'UTF-8//IGNORE', $subject);
+		$utf8Ignored = iconv('UTF-8', 'UTF-8//IGNORE', $subject);
+		if ($utf8Ignored === false) {
+			// Give up
+			return $subject;
+		}
+		return $utf8Ignored;
 	}
 
 	private function parseHeaders(Horde_Imap_Client_Data_Fetch $fetch): void {
